@@ -3,7 +3,7 @@
  */
 
 /*
- * Copyright (C) 2017-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2017-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -157,6 +157,16 @@ RTDECL(uint8_t) RTFsIsoMakerGetRockRidgeLevel(RTFSISOMAKER hIsoMaker);
  */
 RTDECL(uint8_t) RTFsIsoMakerGetJolietRockRidgeLevel(RTFSISOMAKER hIsoMaker);
 
+/**
+ * Sets the UDF ECMA standard version/level.
+ *
+ * @returns IPRT status code
+ * @param   hIsoMaker           The ISO maker handle.
+ * @param   uEcmaLevel          The ECMA standard version (2 or 3), or 0 to
+ *                              disable UDF.
+ */
+RTDECL(int) RTFsIsoMakerSetUdfLevel(RTFSISOMAKER hIsoMaker, uint8_t uEcmaLevel);
+
 /**
  * Changes the file attribute (mode, owner, group) inherit style (from source).
  *
@@ -759,6 +769,8 @@ RTDECL(int) RTFsIsoMakerImport(RTFSISOMAKER hIsoMaker, RTVFSFILE hIsoFile, uint3
 #define RTFSISOMK_IMPORT_F_NO_J_ABSTRACT_FID    RT_BIT_32(23) /**< Don't import the abstract file ID joliet descriptor field. */
 #define RTFSISOMK_IMPORT_F_NO_J_BIBLIO_FID      RT_BIT_32(24) /**< Don't import the bibliographic file ID joliet descriptor field. */
 
+#define RTFSISOMK_IMPORT_F_NO_U_VOLUME_ID       RT_BIT_32(25) /**< Don't import the UDF volume ID (label). */
+
 #define RTFSISOMK_IMPORT_F_VALID_MASK           UINT32_C(0x01ffffff)
 /** @} */
 
