@@ -66,7 +66,6 @@ static const uint64_t priority_to_modifier[] = {
    [MODIFIER_PRIORITY_LINEAR] = DRM_FORMAT_MOD_LINEAR,
    [MODIFIER_PRIORITY_X] = I915_FORMAT_MOD_X_TILED,
    [MODIFIER_PRIORITY_Y] = I915_FORMAT_MOD_Y_TILED,
-   [MODIFIER_PRIORITY_Y_CCS] = I915_FORMAT_MOD_Y_TILED_CCS,
 };
 
 static bool
@@ -76,8 +75,6 @@ modifier_is_supported(const struct intel_device_info *devinfo,
 {
    /* XXX: do something real */
    switch (modifier) {
-   case I915_FORMAT_MOD_Y_TILED_CCS:
-      return false;
    case I915_FORMAT_MOD_Y_TILED:
       if (bind & PIPE_BIND_SCANOUT)
          return false;
@@ -105,9 +102,6 @@ select_best_modifier(struct intel_device_info *devinfo,
          continue;
 
       switch (modifiers[i]) {
-      case I915_FORMAT_MOD_Y_TILED_CCS:
-         prio = MAX2(prio, MODIFIER_PRIORITY_Y_CCS);
-         break;
       case I915_FORMAT_MOD_Y_TILED:
          prio = MAX2(prio, MODIFIER_PRIORITY_Y);
          break;
@@ -189,11 +183,8 @@ crocus_resource_configure_main(const struct crocus_screen *screen,
 
       tiling_flags = 1 << res->mod_info->tiling;
    } else {
-      if (templ->bind & PIPE_BIND_RENDER_TARGET && devinfo->ver < 6) {
-         modifier = I915_FORMAT_MOD_X_TILED;
-         res->mod_info = isl_drm_modifier_get_info(modifier);
-         tiling_flags = 1 << res->mod_info->tiling;
-      }
+      if (templ->bind & PIPE_BIND_RENDER_TARGET && devinfo->ver < 6)
+         tiling_flags &= ISL_TILING_LINEAR_BIT | ISL_TILING_X_BIT;
       /* Use linear for staging buffers */
       if (templ->usage == PIPE_USAGE_STAGING ||
           templ->bind & (PIPE_BIND_LINEAR | PIPE_BIND_CURSOR) )
@@ -254,6 +245,15 @@ crocus_resource_configure_main(const struct crocus_screen *screen,
    if (!isl_surf_init_s(&screen->isl_dev, &res->surf, &init_info))
       return false;
 
+   /*
+    * Don't create staging surfaces that will use > half the aperture
+    * since staging implies you are sending to another resource,
+    * which there is no way to fit both into aperture.
+    */
+   if (templ->usage == PIPE_USAGE_STAGING)
+      if (res->surf.size_B > screen->aperture_threshold / 2)
+         return false;
+
    res->internal_format = templ->format;
 
    return true;
@@ -274,7 +274,6 @@ crocus_query_dmabuf_modifiers(struct pipe_screen *pscreen,
       DRM_FORMAT_MOD_LINEAR,
       I915_FORMAT_MOD_X_TILED,
       I915_FORMAT_MOD_Y_TILED,
-      I915_FORMAT_MOD_Y_TILED_CCS,
    };
 
    int supported_mods = 0;
@@ -356,7 +355,7 @@ crocus_alloc_resource(struct pipe_screen *pscreen,
    res->base.b.screen = pscreen;
    res->orig_screen = crocus_pscreen_ref(pscreen);
    pipe_reference_init(&res->base.b.reference, 1);
-   threaded_resource_init(&res->base.b);
+   threaded_resource_init(&res->base.b, false);
 
    if (templ->target == PIPE_BUFFER)
       util_range_init(&res->valid_buffer_range);
@@ -368,7 +367,7 @@ unsigned
 crocus_get_num_logical_layers(const struct crocus_resource *res, unsigned level)
 {
    if (res->surf.dim == ISL_SURF_DIM_3D)
-      return minify(res->surf.logical_level0_px.depth, level);
+      return u_minify(res->surf.logical_level0_px.depth, level);
    else
       return res->surf.logical_level0_px.array_len;
 }
@@ -419,36 +418,31 @@ create_aux_state_map(struct crocus_resource *res, enum isl_aux_state initial)
  */
 static bool
 crocus_resource_configure_aux(struct crocus_screen *screen,
-                              struct crocus_resource *res, bool imported,
+                              struct crocus_resource *res,
                               uint64_t *aux_size_B,
                               uint32_t *alloc_flags)
 {
    const struct intel_device_info *devinfo = &screen->devinfo;
 
-   /* Try to create the auxiliary surfaces allowed by the modifier or by
-    * the user if no modifier is specified.
-    */
-   assert(!res->mod_info || res->mod_info->aux_usage == ISL_AUX_USAGE_NONE);
+   /* Modifiers with compression are not supported. */
+   assert(!res->mod_info ||
+          !isl_drm_modifier_has_aux(res->mod_info->modifier));
 
    const bool has_mcs = devinfo->ver >= 7 && !res->mod_info &&
       isl_surf_get_mcs_surf(&screen->isl_dev, &res->surf, &res->aux.surf);
 
    const bool has_hiz = devinfo->ver >= 6 && !res->mod_info &&
-      !INTEL_DEBUG(DEBUG_NO_HIZ) &&
       isl_surf_get_hiz_surf(&screen->isl_dev, &res->surf, &res->aux.surf);
 
    const bool has_ccs =
-      ((devinfo->ver >= 7 && !res->mod_info && !INTEL_DEBUG(DEBUG_NO_RBC)) ||
-       (res->mod_info && res->mod_info->aux_usage != ISL_AUX_USAGE_NONE)) &&
+      devinfo->ver >= 7 && !res->mod_info &&
       isl_surf_get_ccs_surf(&screen->isl_dev, &res->surf, NULL,
                             &res->aux.surf, 0);
 
    /* Having more than one type of compression is impossible */
    assert(has_ccs + has_mcs + has_hiz <= 1);
 
-   if (res->mod_info && has_ccs) {
-      res->aux.usage = res->mod_info->aux_usage;
-   } else if (has_mcs) {
+   if (has_mcs) {
       res->aux.usage = ISL_AUX_USAGE_MCS;
    } else if (has_hiz) {
       res->aux.usage = ISL_AUX_USAGE_HIZ;
@@ -464,9 +458,8 @@ crocus_resource_configure_aux(struct crocus_screen *screen,
 
    switch (res->aux.usage) {
    case ISL_AUX_USAGE_NONE:
-      /* Having no aux buffer is only okay if there's no modifier with aux. */
       res->aux.surf.levels = 0;
-      return !res->mod_info || res->mod_info->aux_usage == ISL_AUX_USAGE_NONE;
+      return true;
    case ISL_AUX_USAGE_HIZ:
       initial_state = ISL_AUX_STATE_AUX_INVALID;
       break;
@@ -496,11 +489,7 @@ crocus_resource_configure_aux(struct crocus_screen *screen,
        * For CCS_D, do the same thing.  On Gen9+, this avoids having any
        * undefined bits in the aux buffer.
        */
-      if (imported)
-         initial_state =
-            isl_drm_modifier_get_default_aux_state(res->mod_info->modifier);
-      else
-         initial_state = ISL_AUX_STATE_PASS_THROUGH;
+      initial_state = ISL_AUX_STATE_PASS_THROUGH;
       *alloc_flags |= BO_ALLOC_ZEROED;
       break;
    default:
@@ -513,9 +502,7 @@ crocus_resource_configure_aux(struct crocus_screen *screen,
       return false;
 
    /* Increase the aux offset if the main and aux surfaces will share a BO. */
-   res->aux.offset =
-      !res->mod_info || res->mod_info->aux_usage == res->aux.usage ?
-      ALIGN(res->surf.size_B, res->aux.surf.alignment_B) : 0;
+   res->aux.offset = (uint32_t)align64(res->surf.size_B, res->aux.surf.alignment_B);
    uint64_t size = res->aux.surf.size_B;
 
    /* Allocate space in the buffer for storing the clear color. On modern
@@ -528,7 +515,7 @@ crocus_resource_configure_aux(struct crocus_screen *screen,
     * starts at a 4K alignment. We believe that 256B might be enough, but due
     * to lack of testing we will leave this as 4K for now.
     */
-   size = ALIGN(size, 4096);
+   size = align64(size, 4096);
    *aux_size_B = size;
 
    if (isl_aux_usage_has_hiz(res->aux.usage)) {
@@ -586,7 +573,7 @@ crocus_resource_alloc_separate_aux(struct crocus_screen *screen,
 {
    uint32_t alloc_flags;
    uint64_t size;
-   if (!crocus_resource_configure_aux(screen, res, false, &size, &alloc_flags))
+   if (!crocus_resource_configure_aux(screen, res, &size, &alloc_flags))
       return false;
 
    if (size == 0)
@@ -610,31 +597,6 @@ crocus_resource_alloc_separate_aux(struct crocus_screen *screen,
    return true;
 }
 
-void
-crocus_resource_finish_aux_import(struct pipe_screen *pscreen,
-                                  struct crocus_resource *res)
-{
-   struct crocus_screen *screen = (struct crocus_screen *)pscreen;
-   assert(crocus_resource_unfinished_aux_import(res));
-   assert(!res->mod_info->supports_clear_color);
-
-   struct crocus_resource *aux_res = (void *) res->base.b.next;
-   assert(aux_res->aux.surf.row_pitch_B && aux_res->aux.offset &&
-          aux_res->aux.bo);
-
-   assert(res->bo == aux_res->aux.bo);
-   crocus_bo_reference(aux_res->aux.bo);
-   res->aux.bo = aux_res->aux.bo;
-
-   res->aux.offset = aux_res->aux.offset;
-
-   assert(res->bo->size >= (res->aux.offset + res->aux.surf.size_B));
-   assert(aux_res->aux.surf.row_pitch_B == res->aux.surf.row_pitch_B);
-
-   crocus_resource_destroy(&screen->base, res->base.b.next);
-   res->base.b.next = NULL;
-}
-
 static struct pipe_resource *
 crocus_resource_create_for_buffer(struct pipe_screen *pscreen,
                                   const struct pipe_resource *templ)
@@ -686,12 +648,12 @@ crocus_resource_create_with_modifiers(struct pipe_screen *pscreen,
    if (templ->usage == PIPE_USAGE_STAGING &&
        templ->bind == PIPE_BIND_DEPTH_STENCIL &&
        devinfo->ver < 6)
-      return NULL;
+      goto fail;
 
    const bool isl_surf_created_successfully =
       crocus_resource_configure_main(screen, res, templ, modifier, 0);
    if (!isl_surf_created_successfully)
-      return NULL;
+      goto fail;
 
    const char *name = "miptree";
 
@@ -699,10 +661,14 @@ crocus_resource_create_with_modifiers(struct pipe_screen *pscreen,
    if (templ->usage == PIPE_USAGE_STAGING)
       flags |= BO_ALLOC_COHERENT;
 
+   /* Scanout buffers need to be WC. */
+   if (templ->bind & PIPE_BIND_SCANOUT)
+      flags |= BO_ALLOC_SCANOUT;
+
    uint64_t aux_size = 0;
    uint32_t aux_preferred_alloc_flags;
 
-   if (!crocus_resource_configure_aux(screen, res, false, &aux_size,
+   if (!crocus_resource_configure_aux(screen, res, &aux_size,
                                       &aux_preferred_alloc_flags)) {
       goto fail;
    }
@@ -749,7 +715,6 @@ crocus_resource_create_with_modifiers(struct pipe_screen *pscreen,
    return &res->base.b;
 
 fail:
-   fprintf(stderr, "XXX: resource creation failed\n");
    crocus_resource_destroy(pscreen, &res->base.b);
    return NULL;
 
@@ -838,46 +803,24 @@ crocus_resource_from_handle(struct pipe_screen *pscreen,
    res->offset = whandle->offset;
    res->external_format = whandle->format;
 
-   if (whandle->plane < util_format_get_num_planes(whandle->format)) {
-      const uint64_t modifier =
-         whandle->modifier != DRM_FORMAT_MOD_INVALID ?
-         whandle->modifier : tiling_to_modifier(res->bo->tiling_mode);
+   assert(whandle->plane < util_format_get_num_planes(whandle->format));
+   const uint64_t modifier =
+      whandle->modifier != DRM_FORMAT_MOD_INVALID ?
+      whandle->modifier : tiling_to_modifier(res->bo->tiling_mode);
 
-      UNUSED const bool isl_surf_created_successfully =
-         crocus_resource_configure_main(screen, res, templ, modifier,
-                                        whandle->stride);
-      assert(isl_surf_created_successfully);
-      assert(res->bo->tiling_mode ==
-             isl_tiling_to_i915_tiling(res->surf.tiling));
+   UNUSED const bool isl_surf_created_successfully =
+      crocus_resource_configure_main(screen, res, templ, modifier,
+                                     whandle->stride);
+   assert(isl_surf_created_successfully);
+   assert(res->bo->tiling_mode ==
+          isl_tiling_to_i915_tiling(res->surf.tiling));
 
-      // XXX: create_ccs_buf_for_image?
-      if (whandle->modifier == DRM_FORMAT_MOD_INVALID) {
-         if (!crocus_resource_alloc_separate_aux(screen, res))
-            goto fail;
-      } else {
-         if (res->mod_info->aux_usage != ISL_AUX_USAGE_NONE) {
-            uint32_t alloc_flags;
-            uint64_t size;
-            UNUSED bool ok = crocus_resource_configure_aux(screen, res, true, &size,
-                                                           &alloc_flags);
-            assert(ok);
-            /* The gallium dri layer will create a separate plane resource
-             * for the aux image. crocus_resource_finish_aux_import will
-             * merge the separate aux parameters back into a single
-             * crocus_resource.
-             */
-         }
-      }
+   // XXX: create_ccs_buf_for_image?
+   if (whandle->modifier == DRM_FORMAT_MOD_INVALID) {
+      if (!crocus_resource_alloc_separate_aux(screen, res))
+         goto fail;
    } else {
-      /* Save modifier import information to reconstruct later. After
-       * import, this will be available under a second image accessible
-       * from the main image with res->base.next. See
-       * crocus_resource_finish_aux_import.
-       */
-      res->aux.surf.row_pitch_B = whandle->stride;
-      res->aux.offset = whandle->offset;
-      res->aux.bo = res->bo;
-      res->bo = NULL;
+      assert(!isl_drm_modifier_has_aux(whandle->modifier));
    }
 
    return &res->base.b;
@@ -924,13 +867,15 @@ crocus_flush_resource(struct pipe_context *ctx, struct pipe_resource *resource)
 {
    struct crocus_context *ice = (struct crocus_context *)ctx;
    struct crocus_resource *res = (void *) resource;
-   const struct isl_drm_modifier_info *mod = res->mod_info;
+
+   /* Modifiers with compression are not supported. */
+   assert(!res->mod_info ||
+          !isl_drm_modifier_has_aux(res->mod_info->modifier));
 
    crocus_resource_prepare_access(ice, res,
                                   0, INTEL_REMAINING_LEVELS,
                                   0, INTEL_REMAINING_LAYERS,
-                                  mod ? mod->aux_usage : ISL_AUX_USAGE_NONE,
-                                  mod ? mod->supports_clear_color : false);
+                                  ISL_AUX_USAGE_NONE, false);
 }
 
 static void
@@ -938,15 +883,15 @@ crocus_resource_disable_aux_on_first_query(struct pipe_resource *resource,
                                            unsigned usage)
 {
    struct crocus_resource *res = (struct crocus_resource *)resource;
-   bool mod_with_aux =
-      res->mod_info && res->mod_info->aux_usage != ISL_AUX_USAGE_NONE;
+
+   /* Modifiers with compression are not supported. */
+   assert(!res->mod_info ||
+          !isl_drm_modifier_has_aux(res->mod_info->modifier));
 
    /* Disable aux usage if explicit flush not set and this is the first time
-    * we are dealing with this resource and the resource was not created with
-    * a modifier with aux.
+    * we are dealing with this resource.
     */
-   if (!mod_with_aux &&
-       (!(usage & PIPE_HANDLE_USAGE_EXPLICIT_FLUSH) && res->aux.usage != 0) &&
+   if ((!(usage & PIPE_HANDLE_USAGE_EXPLICIT_FLUSH) && res->aux.usage != 0) &&
        p_atomic_read(&resource->reference.count) == 1) {
       crocus_resource_disable_aux(res);
    }
@@ -965,35 +910,31 @@ crocus_resource_get_param(struct pipe_screen *pscreen,
 {
    struct crocus_screen *screen = (struct crocus_screen *)pscreen;
    struct crocus_resource *res = (struct crocus_resource *)resource;
-   bool mod_with_aux =
-      res->mod_info && res->mod_info->aux_usage != ISL_AUX_USAGE_NONE;
-   bool wants_aux = mod_with_aux && plane > 0;
+
+   /* Modifiers with compression are not supported. */
+   assert(!res->mod_info ||
+          !isl_drm_modifier_has_aux(res->mod_info->modifier));
+
    bool result;
    unsigned handle;
 
-   if (crocus_resource_unfinished_aux_import(res))
-      crocus_resource_finish_aux_import(pscreen, res);
-
-   struct crocus_bo *bo = wants_aux ? res->aux.bo : res->bo;
+   struct crocus_bo *bo = res->bo;
 
    crocus_resource_disable_aux_on_first_query(resource, handle_usage);
 
    switch (param) {
-   case PIPE_RESOURCE_PARAM_NPLANES:
-      if (mod_with_aux) {
-         *value = util_format_get_num_planes(res->external_format);
-      } else {
-         unsigned count = 0;
-         for (struct pipe_resource *cur = resource; cur; cur = cur->next)
-            count++;
-         *value = count;
-      }
+   case PIPE_RESOURCE_PARAM_NPLANES: {
+      unsigned count = 0;
+      for (struct pipe_resource *cur = resource; cur; cur = cur->next)
+         count++;
+      *value = count;
       return true;
+      }
    case PIPE_RESOURCE_PARAM_STRIDE:
-      *value = wants_aux ? res->aux.surf.row_pitch_B : res->surf.row_pitch_B;
+      *value = res->surf.row_pitch_B;
       return true;
    case PIPE_RESOURCE_PARAM_OFFSET:
-      *value = wants_aux ? res->aux.offset : 0;
+      *value = 0;
       return true;
    case PIPE_RESOURCE_PARAM_MODIFIER:
       *value = res->mod_info ? res->mod_info->modifier :
@@ -1035,30 +976,24 @@ crocus_resource_get_handle(struct pipe_screen *pscreen,
 {
    struct crocus_screen *screen = (struct crocus_screen *) pscreen;
    struct crocus_resource *res = (struct crocus_resource *)resource;
-   bool mod_with_aux =
-      res->mod_info && res->mod_info->aux_usage != ISL_AUX_USAGE_NONE;
+
+   /* Modifiers with compression are not supported. */
+   assert(!res->mod_info ||
+          !isl_drm_modifier_has_aux(res->mod_info->modifier));
 
    crocus_resource_disable_aux_on_first_query(resource, usage);
 
    struct crocus_bo *bo;
-   if (mod_with_aux && whandle->plane > 0) {
-      assert(res->aux.bo);
-      bo = res->aux.bo;
-      whandle->stride = res->aux.surf.row_pitch_B;
-      whandle->offset = res->aux.offset;
-   } else {
-      /* If this is a buffer, stride should be 0 - no need to special case */
-      whandle->stride = res->surf.row_pitch_B;
-      bo = res->bo;
-   }
+   /* If this is a buffer, stride should be 0 - no need to special case */
+   whandle->stride = res->surf.row_pitch_B;
+   bo = res->bo;
    whandle->format = res->external_format;
    whandle->modifier =
       res->mod_info ? res->mod_info->modifier
                     : tiling_to_modifier(res->bo->tiling_mode);
 
 #ifndef NDEBUG
-   enum isl_aux_usage allowed_usage =
-      res->mod_info ? res->mod_info->aux_usage : ISL_AUX_USAGE_NONE;
+   enum isl_aux_usage allowed_usage = ISL_AUX_USAGE_NONE;
 
    if (res->aux.usage != allowed_usage) {
       enum isl_aux_state aux_state = crocus_resource_get_aux_state(res, 0, 0);
@@ -1246,7 +1181,12 @@ crocus_map_copy_region(struct crocus_transfer *map)
       templ.target = PIPE_TEXTURE_2D;
 
    map->staging = crocus_resource_create(pscreen, &templ);
-   assert(map->staging);
+
+   /* If we fail to create a staging resource, the caller will fallback
+    * to mapping directly on the CPU.
+    */
+   if (!map->staging)
+      return;
 
    if (templ.target != PIPE_BUFFER) {
       struct isl_surf *surf = &((struct crocus_resource *) map->staging)->surf;
@@ -1632,19 +1572,18 @@ crocus_transfer_map(struct pipe_context *ctx,
 
    struct crocus_transfer *map;
    if (usage & TC_TRANSFER_MAP_THREADED_UNSYNC)
-      map = slab_alloc(&ice->transfer_pool_unsync);
+      map = slab_zalloc(&ice->transfer_pool_unsync);
    else
-      map = slab_alloc(&ice->transfer_pool);
+      map = slab_zalloc(&ice->transfer_pool);
 
    struct pipe_transfer *xfer = &map->base.b;
 
    if (!map)
       return NULL;
 
-   memset(map, 0, sizeof(*map));
    map->dbg = &ice->dbg;
 
-   map->has_swizzling = ((struct crocus_screen *)ctx->screen)->has_swizzling;
+   map->has_swizzling = screen->devinfo.has_bit6_swizzle;
    pipe_resource_reference(&xfer->resource, resource);
    xfer->level = level;
    xfer->usage = usage;
@@ -1692,9 +1631,12 @@ crocus_transfer_map(struct pipe_context *ctx,
       map->batch = &ice->batches[CROCUS_BATCH_RENDER];
       map->blorp = &ice->blorp;
       crocus_map_copy_region(map);
-   } else {
-      /* Otherwise we're free to map on the CPU. */
+   }
 
+   /* If we've requested a direct mapping, or crocus_map_copy_region failed
+    * to create a staging resource, then map it directly on the CPU.
+    */
+   if (!map->ptr) {
       if (resource->target != PIPE_BUFFER) {
          crocus_resource_access_raw(ice, res,
                                     level, box->z, box->depth,
@@ -1995,15 +1937,22 @@ crocus_init_screen_resource_functions(struct pipe_screen *pscreen)
    pscreen->resource_destroy = u_transfer_helper_resource_destroy;
    pscreen->memobj_create_from_handle = crocus_memobj_create_from_handle;
    pscreen->memobj_destroy = crocus_memobj_destroy;
+
+   enum u_transfer_helper_flags transfer_flags = U_TRANSFER_HELPER_MSAA_MAP;
+   if (screen->devinfo.ver >= 6) {
+      transfer_flags |= U_TRANSFER_HELPER_SEPARATE_Z32S8 |
+               U_TRANSFER_HELPER_SEPARATE_STENCIL;
+   }
+
    pscreen->transfer_helper =
-      u_transfer_helper_create(&transfer_vtbl, screen->devinfo.ver >= 6,
-                               screen->devinfo.ver >= 6, false, true);
+      u_transfer_helper_create(&transfer_vtbl, transfer_flags);
 }
 
 void
 crocus_init_resource_functions(struct pipe_context *ctx)
 {
    ctx->flush_resource = crocus_flush_resource;
+   ctx->clear_buffer = u_default_clear_buffer;
    ctx->invalidate_resource = crocus_invalidate_resource;
    ctx->buffer_map = u_transfer_helper_transfer_map;
    ctx->texture_map = u_transfer_helper_transfer_map;
