@@ -50,7 +50,6 @@ unsigned i915_debug = 0;
 
 DEBUG_GET_ONCE_FLAGS_OPTION(i915_debug, "I915_DEBUG", i915_debug_options, 0)
 DEBUG_GET_ONCE_BOOL_OPTION(i915_no_tiling, "I915_NO_TILING", false)
-DEBUG_GET_ONCE_BOOL_OPTION(i915_lie, "I915_LIE", true)
 DEBUG_GET_ONCE_BOOL_OPTION(i915_use_blitter, "I915_USE_BLITTER", true)
 
 void
@@ -58,7 +57,6 @@ i915_debug_init(struct i915_screen *is)
 {
    i915_debug = debug_get_option_i915_debug();
    is->debug.tiling = !debug_get_option_i915_no_tiling();
-   is->debug.lie = debug_get_option_i915_lie();
    is->debug.use_blitter = debug_get_option_i915_use_blitter();
 }
 
@@ -212,7 +210,7 @@ debug_variable_length_prim(struct debug_stream *stream)
    const char *prim = get_prim_name(ptr[0]);
    unsigned i, len;
 
-   ushort *idx = (ushort *)(ptr + 1);
+   uint16_t *idx = (uint16_t *)(ptr + 1);
    for (i = 0; idx[i] != 0xffff; i++)
       ;
 
