@@ -29,7 +29,8 @@
 
 #include "util/u_inlines.h"
 
-#include "util/u_format.h"
+#include "util/format/u_format.h"
+#include "util/u_draw.h"
 #include "util/u_memory.h"
 #include "util/u_upload_mgr.h"
 #include "util/u_prim.h"
@@ -39,6 +40,8 @@
 #include "r300_screen_buffer.h"
 #include "r300_emit.h"
 #include "r300_reg.h"
+#include "r300_vs.h"
+#include "r300_fs.h"
 
 #include <limits.h>
 
@@ -94,12 +97,12 @@ static uint32_t r300_provoking_vertex_fixes(struct r300_context *r300,
 
     if (rs->rs.flatshade_first) {
         switch (mode) {
-            case PIPE_PRIM_TRIANGLE_FAN:
+            case MESA_PRIM_TRIANGLE_FAN:
                 color_control |= R300_GA_COLOR_CONTROL_PROVOKING_VERTEX_SECOND;
                 break;
-            case PIPE_PRIM_QUADS:
-            case PIPE_PRIM_QUAD_STRIP:
-            case PIPE_PRIM_POLYGON:
+            case MESA_PRIM_QUADS:
+            case MESA_PRIM_QUAD_STRIP:
+            case MESA_PRIM_POLYGON:
                 color_control |= R300_GA_COLOR_CONTROL_PROVOKING_VERTEX_LAST;
                 break;
             default:
@@ -160,7 +163,7 @@ static void r300_split_index_bias(struct r300_context *r300, int index_bias,
         max_neg_bias = INT_MAX;
         for (i = 0; i < r300->velems->count; i++) {
             vb = &vbufs[velem[i].vertex_buffer_index];
-            size = (vb->buffer_offset + velem[i].src_offset) / vb->stride;
+            size = (vb->buffer_offset + velem[i].src_offset) / velem[i].src_stride;
             max_neg_bias = MIN2(max_neg_bias, size);
         }
 
@@ -190,14 +193,14 @@ enum r300_prepare_flags {
  * \param cs_dwords     The number of dwords to reserve in CS.
  * \return TRUE if the CS was flushed
  */
-static boolean r300_reserve_cs_dwords(struct r300_context *r300,
-                                      enum r300_prepare_flags flags,
-                                      unsigned cs_dwords)
+static bool r300_reserve_cs_dwords(struct r300_context *r300,
+                                   enum r300_prepare_flags flags,
+                                   unsigned cs_dwords)
 {
-    boolean flushed        = FALSE;
-    boolean emit_states    = flags & PREP_EMIT_STATES;
-    boolean emit_vertex_arrays       = flags & PREP_EMIT_VARRAYS;
-    boolean emit_vertex_arrays_swtcl = flags & PREP_EMIT_VARRAYS_SWTCL;
+    bool flushed        = false;
+    bool emit_states    = flags & PREP_EMIT_STATES;
+    bool emit_vertex_arrays       = flags & PREP_EMIT_VARRAYS;
+    bool emit_vertex_arrays_swtcl = flags & PREP_EMIT_VARRAYS_SWTCL;
 
     /* Add dirty state, index offset, and AOS. */
     if (emit_states)
@@ -215,9 +218,9 @@ static boolean r300_reserve_cs_dwords(struct r300_context *r300,
     cs_dwords += r300_get_num_cs_end_dwords(r300);
 
     /* Reserve requested CS space. */
-    if (!r300->rws->cs_check_space(r300->cs, cs_dwords)) {
-        r300_flush(&r300->context, RADEON_FLUSH_ASYNC, NULL);
-        flushed = TRUE;
+    if (!r300->rws->cs_check_space(&r300->cs, cs_dwords)) {
+        r300_flush(&r300->context, PIPE_FLUSH_ASYNC, NULL);
+        flushed = true;
     }
 
     return flushed;
@@ -233,17 +236,17 @@ static boolean r300_reserve_cs_dwords(struct r300_context *r300,
  * \param instance_id   Index of instance to render
  * \return TRUE if rendering should be skipped
  */
-static boolean r300_emit_states(struct r300_context *r300,
-                                enum r300_prepare_flags flags,
-                                struct pipe_resource *index_buffer,
-                                int buffer_offset,
-                                int index_bias, int instance_id)
+static bool r300_emit_states(struct r300_context *r300,
+                             enum r300_prepare_flags flags,
+                             struct pipe_resource *index_buffer,
+                             int buffer_offset,
+                             int index_bias, int instance_id)
 {
-    boolean emit_states    = flags & PREP_EMIT_STATES;
-    boolean emit_vertex_arrays       = flags & PREP_EMIT_VARRAYS;
-    boolean emit_vertex_arrays_swtcl = flags & PREP_EMIT_VARRAYS_SWTCL;
-    boolean indexed        = flags & PREP_INDEXED;
-    boolean validate_vbos  = flags & PREP_VALIDATE_VBOS;
+    bool emit_states    = flags & PREP_EMIT_STATES;
+    bool emit_vertex_arrays       = flags & PREP_EMIT_VARRAYS;
+    bool emit_vertex_arrays_swtcl = flags & PREP_EMIT_VARRAYS_SWTCL;
+    bool indexed        = flags & PREP_INDEXED;
+    bool validate_vbos  = flags & PREP_VALIDATE_VBOS;
 
     /* Validate buffers and emit dirty state if needed. */
     if (emit_states || (emit_vertex_arrays && validate_vbos)) {
@@ -251,7 +254,7 @@ static boolean r300_emit_states(struct r300_context *r300,
                                        index_buffer)) {
            fprintf(stderr, "r300: CS space validation failed. "
                    "(not enough memory?) Skipping rendering.\n");
-           return FALSE;
+           return false;
         }
     }
 
@@ -272,7 +275,7 @@ static boolean r300_emit_states(struct r300_context *r300,
          r300->vertex_arrays_instance_id != instance_id)) {
         r300_emit_vertex_arrays(r300, buffer_offset, indexed, instance_id);
 
-        r300->vertex_arrays_dirty = FALSE;
+        r300->vertex_arrays_dirty = false;
         r300->vertex_arrays_indexed = indexed;
         r300->vertex_arrays_offset = buffer_offset;
         r300->vertex_arrays_instance_id = instance_id;
@@ -281,7 +284,7 @@ static boolean r300_emit_states(struct r300_context *r300,
     if (emit_vertex_arrays_swtcl)
         r300_emit_vertex_arrays_swtcl(r300, indexed);
 
-    return TRUE;
+    return true;
 }
 
 /**
@@ -296,13 +299,13 @@ static boolean r300_emit_states(struct r300_context *r300,
  * \param instance_id The instance to render.
  * \return TRUE if rendering should be skipped
  */
-static boolean r300_prepare_for_rendering(struct r300_context *r300,
-                                          enum r300_prepare_flags flags,
-                                          struct pipe_resource *index_buffer,
-                                          unsigned cs_dwords,
-                                          int buffer_offset,
-                                          int index_bias,
-                                          int instance_id)
+static bool r300_prepare_for_rendering(struct r300_context *r300,
+                                       enum r300_prepare_flags flags,
+                                       struct pipe_resource *index_buffer,
+                                       unsigned cs_dwords,
+                                       int buffer_offset,
+                                       int index_bias,
+                                       int instance_id)
 {
     /* Make sure there is enough space in the command stream and emit states. */
     if (r300_reserve_cs_dwords(r300, flags, cs_dwords))
@@ -312,20 +315,20 @@ static boolean r300_prepare_for_rendering(struct r300_context *r300,
                             index_bias, instance_id);
 }
 
-static boolean immd_is_good_idea(struct r300_context *r300,
-                                 unsigned count)
+static bool immd_is_good_idea(struct r300_context *r300,
+                              unsigned count)
 {
     if (DBG_ON(r300, DBG_NO_IMMD)) {
-        return FALSE;
+        return false;
     }
 
     if (count * r300->velems->vertex_size_dwords > IMMD_DWORDS) {
-        return FALSE;
+        return false;
     }
 
     /* Buffers can only be used for read by r300 (except query buffers, but
-     * those can't be bound by a state tracker as vertex buffers). */
-    return TRUE;
+     * those can't be bound by an gallium frontend as vertex buffers). */
+    return true;
 }
 
 /*****************************************************************************
@@ -333,7 +336,8 @@ static boolean immd_is_good_idea(struct r300_context *r300,
  ****************************************************************************/
 
 static void r300_draw_arrays_immediate(struct r300_context *r300,
-                                       const struct pipe_draw_info *info)
+                                       const struct pipe_draw_info *info,
+                                       const struct pipe_draw_start_count_bias *draw)
 {
     struct pipe_vertex_element* velem;
     struct pipe_vertex_buffer* vbuf;
@@ -344,7 +348,7 @@ static void r300_draw_arrays_immediate(struct r300_context *r300,
     unsigned vertex_size = r300->velems->vertex_size_dwords;
 
     /* The number of dwords for this draw operation. */
-    unsigned dwords = 4 + info->count * vertex_size;
+    unsigned dwords = 4 + draw->count * vertex_size;
 
     /* Size of the vertex element, in dwords. */
     unsigned size[PIPE_MAX_ATTRIBS];
@@ -368,28 +372,28 @@ static void r300_draw_arrays_immediate(struct r300_context *r300,
         size[i] = r300->velems->format_size[i] / 4;
         vbi = velem->vertex_buffer_index;
         vbuf = &r300->vertex_buffer[vbi];
-        stride[i] = vbuf->stride / 4;
+        stride[i] = velem->src_stride / 4;
 
         /* Map the buffer. */
         if (!map[vbi]) {
-            map[vbi] = (uint32_t*)r300->rws->buffer_map(
+            map[vbi] = (uint32_t*)r300->rws->buffer_map(r300->rws,
                 r300_resource(vbuf->buffer.resource)->buf,
-                r300->cs, PIPE_TRANSFER_READ | PIPE_TRANSFER_UNSYNCHRONIZED);
-            map[vbi] += (vbuf->buffer_offset / 4) + stride[i] * info->start;
+                &r300->cs, PIPE_MAP_READ | PIPE_MAP_UNSYNCHRONIZED);
+            map[vbi] += (vbuf->buffer_offset / 4) + stride[i] * draw->start;
         }
         mapelem[i] = map[vbi] + (velem->src_offset / 4);
     }
 
-    r300_emit_draw_init(r300, info->mode, info->count-1);
+    r300_emit_draw_init(r300, info->mode, draw->count-1);
 
     BEGIN_CS(dwords);
     OUT_CS_REG(R300_VAP_VTX_SIZE, vertex_size);
-    OUT_CS_PKT3(R300_PACKET3_3D_DRAW_IMMD_2, info->count * vertex_size);
-    OUT_CS(R300_VAP_VF_CNTL__PRIM_WALK_VERTEX_EMBEDDED | (info->count << 16) |
+    OUT_CS_PKT3(R300_PACKET3_3D_DRAW_IMMD_2, draw->count * vertex_size);
+    OUT_CS(R300_VAP_VF_CNTL__PRIM_WALK_VERTEX_EMBEDDED | (draw->count << 16) |
             r300_translate_primitive(info->mode));
 
     /* Emit vertices. */
-    for (v = 0; v < info->count; v++) {
+    for (v = 0; v < draw->count; v++) {
         for (i = 0; i < vertex_element_count; i++) {
             OUT_CS_TABLE(&mapelem[i][stride[i] * v], size[i]);
         }
@@ -401,7 +405,7 @@ static void r300_emit_draw_arrays(struct r300_context *r300,
                                   unsigned mode,
                                   unsigned count)
 {
-    boolean alt_num_verts = count > 65535;
+    bool alt_num_verts = count > 65535;
     CS_LOCALS(r300);
 
     if (count >= (1 << 24)) {
@@ -433,7 +437,7 @@ static void r300_emit_draw_elements(struct r300_context *r300,
                                     uint16_t *imm_indices3)
 {
     uint32_t count_dwords, offset_dwords;
-    boolean alt_num_verts = count > 65535;
+    bool alt_num_verts = count > 65535;
     CS_LOCALS(r300);
 
     if (count >= (1 << 24)) {
@@ -451,7 +455,7 @@ static void r300_emit_draw_elements(struct r300_context *r300,
      * in the command stream. This will increase start by 3 and make it
      * even. We can then proceed without a fallback. */
     if (indexSize == 2 && (start & 1) &&
-        mode == PIPE_PRIM_TRIANGLES) {
+        mode == MESA_PRIM_TRIANGLES) {
         BEGIN_CS(4);
         OUT_CS_PKT3(R300_PACKET3_3D_DRAW_INDX_2, 2);
         OUT_CS(R300_VAP_VF_CNTL__PRIM_WALK_INDICES | (3 << 16) |
@@ -496,20 +500,21 @@ static void r300_emit_draw_elements(struct r300_context *r300,
 }
 
 static void r300_draw_elements_immediate(struct r300_context *r300,
-                                         const struct pipe_draw_info *info)
+                                         const struct pipe_draw_info *info,
+                                         const struct pipe_draw_start_count_bias *draw)
 {
     const uint8_t *ptr1;
     const uint16_t *ptr2;
     const uint32_t *ptr4;
     unsigned index_size = info->index_size;
-    unsigned i, count_dwords = index_size == 4 ? info->count :
-                                                 (info->count + 1) / 2;
+    unsigned i, count_dwords = index_size == 4 ? draw->count :
+                                                 (draw->count + 1) / 2;
     CS_LOCALS(r300);
 
     /* 19 dwords for r300_draw_elements_immediate. Give up if the function fails. */
     if (!r300_prepare_for_rendering(r300,
             PREP_EMIT_STATES | PREP_VALIDATE_VBOS | PREP_EMIT_VARRAYS |
-            PREP_INDEXED, NULL, 2+count_dwords, 0, info->index_bias, -1))
+            PREP_INDEXED, NULL, 2+count_dwords, 0, draw->index_bias, -1))
         return;
 
     r300_emit_draw_init(r300, info->mode, info->max_index);
@@ -520,42 +525,42 @@ static void r300_draw_elements_immediate(struct r300_context *r300,
     switch (index_size) {
     case 1:
         ptr1 = (uint8_t*)info->index.user;
-        ptr1 += info->start;
+        ptr1 += draw->start;
 
-        OUT_CS(R300_VAP_VF_CNTL__PRIM_WALK_INDICES | (info->count << 16) |
+        OUT_CS(R300_VAP_VF_CNTL__PRIM_WALK_INDICES | (draw->count << 16) |
                r300_translate_primitive(info->mode));
 
-        if (info->index_bias && !r300->screen->caps.is_r500) {
-            for (i = 0; i < info->count-1; i += 2)
-                OUT_CS(((ptr1[i+1] + info->index_bias) << 16) |
-                        (ptr1[i]   + info->index_bias));
+        if (draw->index_bias && !r300->screen->caps.is_r500) {
+            for (i = 0; i < draw->count-1; i += 2)
+                OUT_CS(((ptr1[i+1] + draw->index_bias) << 16) |
+                        (ptr1[i]   + draw->index_bias));
 
-            if (info->count & 1)
-                OUT_CS(ptr1[i] + info->index_bias);
+            if (draw->count & 1)
+                OUT_CS(ptr1[i] + draw->index_bias);
         } else {
-            for (i = 0; i < info->count-1; i += 2)
+            for (i = 0; i < draw->count-1; i += 2)
                 OUT_CS(((ptr1[i+1]) << 16) |
                         (ptr1[i]  ));
 
-            if (info->count & 1)
+            if (draw->count & 1)
                 OUT_CS(ptr1[i]);
         }
         break;
 
     case 2:
         ptr2 = (uint16_t*)info->index.user;
-        ptr2 += info->start;
+        ptr2 += draw->start;
 
-        OUT_CS(R300_VAP_VF_CNTL__PRIM_WALK_INDICES | (info->count << 16) |
+        OUT_CS(R300_VAP_VF_CNTL__PRIM_WALK_INDICES | (draw->count << 16) |
                r300_translate_primitive(info->mode));
 
-        if (info->index_bias && !r300->screen->caps.is_r500) {
-            for (i = 0; i < info->count-1; i += 2)
-                OUT_CS(((ptr2[i+1] + info->index_bias) << 16) |
-                        (ptr2[i]   + info->index_bias));
+        if (draw->index_bias && !r300->screen->caps.is_r500) {
+            for (i = 0; i < draw->count-1; i += 2)
+                OUT_CS(((ptr2[i+1] + draw->index_bias) << 16) |
+                        (ptr2[i]   + draw->index_bias));
 
-            if (info->count & 1)
-                OUT_CS(ptr2[i] + info->index_bias);
+            if (draw->count & 1)
+                OUT_CS(ptr2[i] + draw->index_bias);
         } else {
             OUT_CS_TABLE(ptr2, count_dwords);
         }
@@ -563,15 +568,15 @@ static void r300_draw_elements_immediate(struct r300_context *r300,
 
     case 4:
         ptr4 = (uint32_t*)info->index.user;
-        ptr4 += info->start;
+        ptr4 += draw->start;
 
-        OUT_CS(R300_VAP_VF_CNTL__PRIM_WALK_INDICES | (info->count << 16) |
+        OUT_CS(R300_VAP_VF_CNTL__PRIM_WALK_INDICES | (draw->count << 16) |
                R300_VAP_VF_CNTL__INDEX_SIZE_32bit |
                r300_translate_primitive(info->mode));
 
-        if (info->index_bias && !r300->screen->caps.is_r500) {
-            for (i = 0; i < info->count; i++)
-                OUT_CS(ptr4[i] + info->index_bias);
+        if (draw->index_bias && !r300->screen->caps.is_r500) {
+            for (i = 0; i < draw->count; i++)
+                OUT_CS(ptr4[i] + draw->index_bias);
         } else {
             OUT_CS_TABLE(ptr4, count_dwords);
         }
@@ -582,22 +587,23 @@ static void r300_draw_elements_immediate(struct r300_context *r300,
 
 static void r300_draw_elements(struct r300_context *r300,
                                const struct pipe_draw_info *info,
+                               const struct pipe_draw_start_count_bias *draw,
                                int instance_id)
 {
     struct pipe_resource *indexBuffer =
        info->has_user_indices ? NULL : info->index.resource;
     unsigned indexSize = info->index_size;
     struct pipe_resource* orgIndexBuffer = indexBuffer;
-    unsigned start = info->start;
-    unsigned count = info->count;
-    boolean alt_num_verts = r300->screen->caps.is_r500 &&
+    unsigned start = draw->start;
+    unsigned count = draw->count;
+    bool alt_num_verts = r300->screen->caps.is_r500 &&
                             count > 65536;
     unsigned short_count;
     int buffer_offset = 0, index_offset = 0; /* for index bias emulation */
     uint16_t indices3[3];
 
-    if (info->index_bias && !r300->screen->caps.is_r500) {
-        r300_split_index_bias(r300, info->index_bias, &buffer_offset,
+    if (draw->index_bias && !r300->screen->caps.is_r500) {
+        r300_split_index_bias(r300, draw->index_bias, &buffer_offset,
                               &index_offset);
     }
 
@@ -607,12 +613,12 @@ static void r300_draw_elements(struct r300_context *r300,
     /* Fallback for misaligned ushort indices. */
     if (indexSize == 2 && (start & 1) && indexBuffer) {
         /* If we got here, then orgIndexBuffer == indexBuffer. */
-        uint16_t *ptr = r300->rws->buffer_map(r300_resource(orgIndexBuffer)->buf,
-                                              r300->cs,
-                                              PIPE_TRANSFER_READ |
-                                              PIPE_TRANSFER_UNSYNCHRONIZED);
+        uint16_t *ptr = r300->rws->buffer_map(r300->rws, r300_resource(orgIndexBuffer)->buf,
+                                              &r300->cs,
+                                              PIPE_MAP_READ |
+                                              PIPE_MAP_UNSYNCHRONIZED);
 
-        if (info->mode == PIPE_PRIM_TRIANGLES) {
+        if (info->mode == MESA_PRIM_TRIANGLES) {
            memcpy(indices3, ptr + start, 6);
         } else {
             /* Copy the mapped index buffer directly to the upload buffer.
@@ -631,7 +637,7 @@ static void r300_draw_elements(struct r300_context *r300,
     /* 19 dwords for emit_draw_elements. Give up if the function fails. */
     if (!r300_prepare_for_rendering(r300,
             PREP_EMIT_STATES | PREP_VALIDATE_VBOS | PREP_EMIT_VARRAYS |
-            PREP_INDEXED, indexBuffer, 19, buffer_offset, info->index_bias,
+            PREP_INDEXED, indexBuffer, 19, buffer_offset, draw->index_bias,
             instance_id))
         goto done;
 
@@ -658,7 +664,7 @@ static void r300_draw_elements(struct r300_context *r300,
             if (count) {
                 if (!r300_prepare_for_rendering(r300,
                         PREP_VALIDATE_VBOS | PREP_EMIT_VARRAYS | PREP_INDEXED,
-                        indexBuffer, 19, buffer_offset, info->index_bias,
+                        indexBuffer, 19, buffer_offset, draw->index_bias,
                         instance_id))
                     goto done;
             }
@@ -673,12 +679,13 @@ done:
 
 static void r300_draw_arrays(struct r300_context *r300,
                              const struct pipe_draw_info *info,
+                             const struct pipe_draw_start_count_bias *draw,
                              int instance_id)
 {
-    boolean alt_num_verts = r300->screen->caps.is_r500 &&
-                            info->count > 65536;
-    unsigned start = info->start;
-    unsigned count = info->count;
+    bool alt_num_verts = r300->screen->caps.is_r500 &&
+                            draw->count > 65536;
+    unsigned start = draw->start;
+    unsigned count = draw->count;
     unsigned short_count;
 
     /* 9 spare dwords for emit_draw_arrays. Give up if the function fails. */
@@ -713,21 +720,23 @@ static void r300_draw_arrays(struct r300_context *r300,
 }
 
 static void r300_draw_arrays_instanced(struct r300_context *r300,
-                                       const struct pipe_draw_info *info)
+                                       const struct pipe_draw_info *info,
+                                       const struct pipe_draw_start_count_bias *draw)
 {
     int i;
 
     for (i = 0; i < info->instance_count; i++)
-        r300_draw_arrays(r300, info, i);
+        r300_draw_arrays(r300, info, draw, i);
 }
 
 static void r300_draw_elements_instanced(struct r300_context *r300,
-                                         const struct pipe_draw_info *info)
+                                         const struct pipe_draw_info *info,
+                                         const struct pipe_draw_start_count_bias *draw)
 {
     int i;
 
     for (i = 0; i < info->instance_count; i++)
-        r300_draw_elements(r300, info, i);
+        r300_draw_elements(r300, info, draw, i);
 }
 
 static unsigned r300_max_vertex_count(struct r300_context *r300)
@@ -743,7 +752,7 @@ static unsigned r300_max_vertex_count(struct r300_context *r300)
 
       /* We're not interested in constant and per-instance attribs. */
       if (!vb->buffer.resource ||
-          !vb->stride ||
+          !velems[i].src_stride ||
           velems[i].instance_divisor) {
          continue;
       }
@@ -764,15 +773,8 @@ static unsigned r300_max_vertex_count(struct r300_context *r300)
       }
       size -= value;
 
-      /* Subtract format_size. */
-      value = r300->velems->format_size[i];
-      if (value >= size) {
-         return 0;
-      }
-      size -= value;
-
       /* Compute the max count. */
-      max_count = 1 + size / vb->stride;
+      max_count = 1 + size / velems[i].src_stride;
       result = MIN2(result, max_count);
    }
    return result;
@@ -780,18 +782,40 @@ static unsigned r300_max_vertex_count(struct r300_context *r300)
 
 
 static void r300_draw_vbo(struct pipe_context* pipe,
-                          const struct pipe_draw_info *dinfo)
+                          const struct pipe_draw_info *dinfo,
+                          unsigned drawid_offset,
+                          const struct pipe_draw_indirect_info *indirect,
+                          const struct pipe_draw_start_count_bias *draws,
+                          unsigned num_draws)
 {
+   if (num_draws > 1) {
+      util_draw_multi(pipe, dinfo, drawid_offset, indirect, draws, num_draws);
+      return;
+   }
+
     struct r300_context* r300 = r300_context(pipe);
     struct pipe_draw_info info = *dinfo;
+    struct pipe_draw_start_count_bias draw = draws[0];
 
     if (r300->skip_rendering ||
-        !u_trim_pipe_prim(info.mode, &info.count)) {
+        !u_trim_pipe_prim(info.mode, &draw.count)) {
         return;
     }
 
+    if (r300->sprite_coord_enable != 0 ||
+        r300_fs(r300)->shader->inputs.pcoord != ATTR_UNUSED) {
+        if ((info.mode == MESA_PRIM_POINTS) != r300->is_point) {
+            r300->is_point = !r300->is_point;
+            r300_mark_atom_dirty(r300, &r300->rs_block_state);
+        }
+    }
+
     r300_update_derived_state(r300);
 
+    /* Skip draw if we failed to compile the vertex shader. */
+    if (r300_vs(r300)->shader->dummy)
+        return;
+
     /* Draw. */
     if (info.index_size) {
         unsigned max_count = r300_max_vertex_count(r300);
@@ -810,23 +834,23 @@ static void r300_draw_vbo(struct pipe_context* pipe,
         info.max_index = max_count - 1;
 
         if (info.instance_count <= 1) {
-            if (info.count <= 8 && info.has_user_indices) {
-                r300_draw_elements_immediate(r300, &info);
+            if (draw.count <= 8 && info.has_user_indices) {
+                r300_draw_elements_immediate(r300, &info, &draw);
             } else {
-                r300_draw_elements(r300, &info, -1);
+                r300_draw_elements(r300, &info, &draw, -1);
             }
         } else {
-            r300_draw_elements_instanced(r300, &info);
+            r300_draw_elements_instanced(r300, &info, &draw);
         }
     } else {
         if (info.instance_count <= 1) {
-            if (immd_is_good_idea(r300, info.count)) {
-                r300_draw_arrays_immediate(r300, &info);
+            if (immd_is_good_idea(r300, draw.count)) {
+                r300_draw_arrays_immediate(r300, &info, &draw);
             } else {
-                r300_draw_arrays(r300, &info, -1);
+                r300_draw_arrays(r300, &info, &draw, -1);
             }
         } else {
-            r300_draw_arrays_instanced(r300, &info);
+            r300_draw_arrays_instanced(r300, &info, &draw);
         }
     }
 }
@@ -838,15 +862,25 @@ static void r300_draw_vbo(struct pipe_context* pipe,
 
 /* SW TCL elements, using Draw. */
 static void r300_swtcl_draw_vbo(struct pipe_context* pipe,
-                                const struct pipe_draw_info *info)
+                                const struct pipe_draw_info *info,
+                                unsigned drawid_offset,
+                                const struct pipe_draw_indirect_info *indirect,
+                                const struct pipe_draw_start_count_bias *draws,
+                                unsigned num_draws)
 {
+   if (num_draws > 1) {
+      util_draw_multi(pipe, info, drawid_offset, indirect, draws, num_draws);
+      return;
+   }
+
     struct r300_context* r300 = r300_context(pipe);
+    struct pipe_draw_start_count_bias draw = draws[0];
 
     if (r300->skip_rendering) {
         return;
     }
 
-    if (!u_trim_pipe_prim(info->mode, (unsigned*)&info->count))
+    if (!u_trim_pipe_prim(info->mode, &draw.count))
        return;
 
     if (info->index_size) {
@@ -857,9 +891,18 @@ static void r300_swtcl_draw_vbo(struct pipe_context* pipe,
                          info->index_size, ~0);
     }
 
+    if (r300->sprite_coord_enable != 0 ||
+        r300_fs(r300)->shader->inputs.pcoord != ATTR_UNUSED) {
+        if ((info->mode == MESA_PRIM_POINTS) != r300->is_point) {
+            r300->is_point = !r300->is_point;
+            r300_mark_atom_dirty(r300, &r300->rs_block_state);
+        }
+    }
+
+
     r300_update_derived_state(r300);
 
-    draw_vbo(r300->draw, info);
+    draw_vbo(r300->draw, info, drawid_offset, NULL, &draw, 1, 0);
     draw_flush(r300->draw);
 }
 
@@ -896,9 +939,9 @@ r300_render_get_vertex_info(struct vbuf_render* render)
     return &r300->vertex_info;
 }
 
-static boolean r300_render_allocate_vertices(struct vbuf_render* render,
-                                             ushort vertex_size,
-                                             ushort count)
+static bool r300_render_allocate_vertices(struct vbuf_render* render,
+                                          uint16_t vertex_size,
+                                          uint16_t count)
 {
     struct r300_render* r300render = r300_render(render);
     struct r300_context* r300 = r300render->r300;
@@ -908,24 +951,25 @@ static boolean r300_render_allocate_vertices(struct vbuf_render* render,
     DBG(r300, DBG_DRAW, "r300: render_allocate_vertices (size: %d)\n", size);
 
     if (!r300->vbo || size + r300->draw_vbo_offset > r300->vbo->size) {
-	pb_reference(&r300->vbo, NULL);
+	radeon_bo_reference(r300->rws, &r300->vbo, NULL);
         r300->vbo = NULL;
         r300render->vbo_ptr = NULL;
 
         r300->vbo = rws->buffer_create(rws,
                                        MAX2(R300_MAX_DRAW_VBO_SIZE, size),
                                        R300_BUFFER_ALIGNMENT,
-                                       RADEON_DOMAIN_GTT, 0);
+                                       RADEON_DOMAIN_GTT,
+                                       RADEON_FLAG_NO_INTERPROCESS_SHARING);
         if (!r300->vbo) {
-            return FALSE;
+            return false;
         }
         r300->draw_vbo_offset = 0;
-        r300render->vbo_ptr = rws->buffer_map(r300->vbo, r300->cs,
-                                              PIPE_TRANSFER_WRITE);
+        r300render->vbo_ptr = rws->buffer_map(rws, r300->vbo, &r300->cs,
+                                              PIPE_MAP_WRITE);
     }
 
     r300render->vertex_size = vertex_size;
-    return TRUE;
+    return true;
 }
 
 static void* r300_render_map_vertices(struct vbuf_render* render)
@@ -940,8 +984,8 @@ static void* r300_render_map_vertices(struct vbuf_render* render)
 }
 
 static void r300_render_unmap_vertices(struct vbuf_render* render,
-                                             ushort min,
-                                             ushort max)
+                                       uint16_t min,
+                                       uint16_t max)
 {
     struct r300_render* r300render = r300_render(render);
     struct r300_context* r300 = r300render->r300;
@@ -964,7 +1008,7 @@ static void r300_render_release_vertices(struct vbuf_render* render)
 }
 
 static void r300_render_set_primitive(struct vbuf_render* render,
-                                      unsigned prim)
+                                      enum mesa_prim prim)
 {
     struct r300_render* r300render = r300_render(render);
 
@@ -1007,7 +1051,7 @@ static void r300_render_draw_arrays(struct vbuf_render* render,
 }
 
 static void r300_render_draw_elements(struct vbuf_render* render,
-                                      const ushort* indices,
+                                      const uint16_t* indices,
                                       uint count)
 {
     struct r300_render* r300render = r300_render(render);
@@ -1122,6 +1166,7 @@ void r300_blitter_draw_rectangle(struct blitter_context *blitter,
 {
     struct r300_context *r300 = r300_context(util_blitter_get_pipe(blitter));
     unsigned last_sprite_coord_enable = r300->sprite_coord_enable;
+    unsigned last_is_point = r300->is_point;
     unsigned width = x2 - x1;
     unsigned height = y2 - y1;
     unsigned vertex_size =
@@ -1148,13 +1193,15 @@ void r300_blitter_draw_rectangle(struct blitter_context *blitter,
     r300->context.bind_vertex_elements_state(&r300->context, vertex_elements_cso);
     r300->context.bind_vs_state(&r300->context, get_vs(blitter));
 
-    if (type == UTIL_BLITTER_ATTRIB_TEXCOORD_XY)
+    if (type == UTIL_BLITTER_ATTRIB_TEXCOORD_XY) {
         r300->sprite_coord_enable = 1;
+        r300->is_point = true;
+    }
 
     r300_update_derived_state(r300);
 
     /* Mark some states we don't care about as non-dirty. */
-    r300->viewport_state.dirty = FALSE;
+    r300->viewport_state.dirty = false;
 
     if (!r300_prepare_for_rendering(r300, PREP_EMIT_STATES, NULL, dwords, 0, 0, -1))
         goto done;
@@ -1207,6 +1254,7 @@ done:
     r300_mark_atom_dirty(r300, &r300->viewport_state);
 
     r300->sprite_coord_enable = last_sprite_coord_enable;
+    r300->is_point = last_is_point;
 }
 
 void r300_init_render_functions(struct r300_context *r300)
