@@ -26,7 +26,7 @@
 #ifndef SVGA_DRAW_H
 #define SVGA_DRAW_H
 
-#include "pipe/p_compiler.h"
+#include "util/compiler.h"
 
 #include "svga_hw_reg.h"
 
@@ -42,7 +42,7 @@ struct svga_hwtnl *svga_hwtnl_create(struct svga_context *svga);
 void svga_hwtnl_destroy(struct svga_hwtnl *hwtnl);
 
 void svga_hwtnl_set_flatshade(struct svga_hwtnl *hwtnl,
-                              boolean flatshade, boolean flatshade_first);
+                              bool flatshade, bool flatshade_first);
 
 void svga_hwtnl_set_fillmode(struct svga_hwtnl *hwtnl, unsigned mode);
 
@@ -59,20 +59,17 @@ svga_hwtnl_vertex_buffers(struct svga_hwtnl *hwtnl,
 
 enum pipe_error
 svga_hwtnl_draw_arrays(struct svga_hwtnl *hwtnl,
-                       enum pipe_prim_type prim, unsigned start, unsigned count,
-                       unsigned start_instance, unsigned instance_count);
+                       enum mesa_prim prim, unsigned start, unsigned count,
+                       unsigned start_instance, unsigned instance_count,
+                       uint8_t vertices_per_patch);
 
 enum pipe_error
 svga_hwtnl_draw_range_elements(struct svga_hwtnl *hwtnl,
-                               struct pipe_resource *indexBuffer,
-                               unsigned index_size,
-                               int index_bias,
-                               unsigned min_index,
-                               unsigned max_index,
-                               enum pipe_prim_type prim, unsigned start, unsigned count,
-                               unsigned start_instance, unsigned instance_count);
+                               const struct pipe_draw_info *info,
+                               const struct pipe_draw_start_count_bias *draw,
+                               unsigned count);
 
-boolean
+bool
 svga_hwtnl_is_buffer_referred(struct svga_hwtnl *hwtnl,
                               struct pipe_resource *buffer);
 
@@ -80,8 +77,4 @@ enum pipe_error svga_hwtnl_flush(struct svga_hwtnl *hwtnl);
 
 void svga_hwtnl_set_index_bias(struct svga_hwtnl *hwtnl, int index_bias);
 
-#ifdef VBOX_WITH_MESA3D_SVGA_INSTANCING
-void svga_hwtnl_set_instance_divisor(struct svga_hwtnl *hwtnl, int velem_index, unsigned instance_divisor);
-#endif
-
 #endif /* SVGA_DRAW_H_ */
