@@ -117,7 +117,7 @@ svga_screen_cache_lookup(struct svga_screen *svgascreen,
    while (curr != &cache->bucket[bucket]) {
       ++tries;
 
-      entry = LIST_ENTRY(struct svga_host_surface_cache_entry, curr, bucket_head);
+      entry = list_entry(curr, struct svga_host_surface_cache_entry, bucket_head);
 
       assert(entry->handle);
 
@@ -163,7 +163,7 @@ svga_screen_cache_lookup(struct svga_screen *svgascreen,
    mtx_unlock(&cache->mutex);
 
    if (SVGA_DEBUG & DEBUG_DMA)
-      debug_printf("%s: cache %s after %u tries (bucket %d)\n", __FUNCTION__,
+      debug_printf("%s: cache %s after %u tries (bucket %d)\n", __func__,
                    handle ? "hit" : "miss", tries, bucket);
 
    return handle;
@@ -216,6 +216,7 @@ svga_screen_cache_shrink(struct svga_screen *svgascreen,
 static void
 svga_screen_cache_add(struct svga_screen *svgascreen,
                       const struct svga_host_surface_cache_key *key,
+                      bool to_invalidate,
                       struct svga_winsys_surface **p_handle)
 {
    struct svga_host_surface_cache *cache = &svgascreen->cache;
@@ -264,16 +265,18 @@ svga_screen_cache_add(struct svga_screen *svgascreen,
       /* An empty entry has no surface associated with it.
        * Use the first empty entry.
        */
-      entry = LIST_ENTRY(struct svga_host_surface_cache_entry,
-                         cache->empty.next, head);
+      entry = list_entry(cache->empty.next,
+                         struct svga_host_surface_cache_entry,
+                         head);
 
       /* Remove from LRU list */
       list_del(&entry->head);
    }
    else if (!list_is_empty(&cache->unused)) {
       /* free the last used buffer and reuse its entry */
-      entry = LIST_ENTRY(struct svga_host_surface_cache_entry,
-                         cache->unused.prev, head);
+      entry = list_entry(cache->unused.prev,
+                         struct svga_host_surface_cache_entry,
+                         head);
       SVGA_DBG(DEBUG_CACHE|DEBUG_DMA,
                "unref sid %p (make space)\n", entry->handle);
 
@@ -297,8 +300,12 @@ svga_screen_cache_add(struct svga_screen *svgascreen,
                "cache sid %p\n", entry->handle);
 
       /* If we don't have gb objects, we don't need to invalidate. */
-      if (sws->have_gb_objects)
-         list_add(&entry->head, &cache->validated);
+      if (sws->have_gb_objects) {
+         if (to_invalidate)
+            list_add(&entry->head, &cache->validated);
+         else
+            list_add(&entry->head, &cache->invalidated);
+      }
       else
          list_add(&entry->head, &cache->invalidated);
 
@@ -339,7 +346,7 @@ svga_screen_cache_flush(struct svga_screen *svgascreen,
    curr = cache->invalidated.next;
    next = curr->next;
    while (curr != &cache->invalidated) {
-      entry = LIST_ENTRY(struct svga_host_surface_cache_entry, curr, head);
+      entry = list_entry(curr, struct svga_host_surface_cache_entry, head);
 
       assert(entry->handle);
 
@@ -365,7 +372,7 @@ svga_screen_cache_flush(struct svga_screen *svgascreen,
    curr = cache->validated.next;
    next = curr->next;
    while (curr != &cache->validated) {
-      entry = LIST_ENTRY(struct svga_host_surface_cache_entry, curr, head);
+      entry = list_entry(curr, struct svga_host_surface_cache_entry, head);
 
       assert(entry->handle);
       assert(svga_have_gb_objects(svga));
@@ -487,16 +494,16 @@ svga_screen_cache_init(struct svga_screen *svgascreen)
 struct svga_winsys_surface *
 svga_screen_surface_create(struct svga_screen *svgascreen,
                            unsigned bind_flags, enum pipe_resource_usage usage,
-                           boolean *validated,
+                           bool *validated,
                            struct svga_host_surface_cache_key *key)
 {
    struct svga_winsys_screen *sws = svgascreen->sws;
    struct svga_winsys_surface *handle = NULL;
-   boolean cachable = SVGA_SURFACE_CACHE_ENABLED && key->cachable;
+   bool cachable = SVGA_SURFACE_CACHE_ENABLED && key->cachable;
 
    SVGA_DBG(DEBUG_CACHE|DEBUG_DMA,
             "%s sz %dx%dx%d mips %d faces %d arraySize %d cachable %d\n",
-            __FUNCTION__,
+            __func__,
             key->size.width,
             key->size.height,
             key->size.depth,
@@ -562,7 +569,7 @@ svga_screen_surface_create(struct svga_screen *svgascreen,
                      key->numMipLevels,
                      key->numFaces,
                      key->arraySize);
-         *validated = TRUE;
+         *validated = true;
       }
    }
 
@@ -570,7 +577,11 @@ svga_screen_surface_create(struct svga_screen *svgascreen,
       /* Unable to recycle surface, allocate a new one */
       unsigned usage = 0;
 
-      if (!key->cachable)
+      /* mark the surface as shareable if the surface is not
+       * cachable or the RENDER_TARGET bind flag is set.
+       */
+      if (!key->cachable ||
+          ((bind_flags & PIPE_BIND_RENDER_TARGET) != 0))
          usage |= SVGA_SURFACE_USAGE_SHARED;
       if (key->scanout)
          usage |= SVGA_SURFACE_USAGE_SCANOUT;
@@ -593,7 +604,7 @@ svga_screen_surface_create(struct svga_screen *svgascreen,
                   key->size.height,
                   key->size.depth);
 
-      *validated = FALSE;
+      *validated = false;
    }
 
    return handle;
@@ -607,6 +618,7 @@ svga_screen_surface_create(struct svga_screen *svgascreen,
 void
 svga_screen_surface_destroy(struct svga_screen *svgascreen,
                             const struct svga_host_surface_cache_key *key,
+                            bool to_invalidate,
                             struct svga_winsys_surface **p_handle)
 {
    struct svga_winsys_screen *sws = svgascreen->sws;
@@ -616,7 +628,7 @@ svga_screen_surface_destroy(struct svga_screen *svgascreen,
     * that case.
     */
    if (SVGA_SURFACE_CACHE_ENABLED && key->cachable) {
-      svga_screen_cache_add(svgascreen, key, p_handle);
+      svga_screen_cache_add(svgascreen, key, to_invalidate, p_handle);
    }
    else {
       SVGA_DBG(DEBUG_DMA,
@@ -642,8 +654,7 @@ svga_screen_cache_dump(const struct svga_screen *svgascreen)
       curr = cache->bucket[bucket].next;
       while (curr && curr != &cache->bucket[bucket]) {
          struct svga_host_surface_cache_entry *entry =
-            LIST_ENTRY(struct svga_host_surface_cache_entry,
-                       curr, bucket_head);
+            list_entry(curr, struct svga_host_surface_cache_entry,bucket_head);
          if (entry->key.format == SVGA3D_BUFFER) {
             debug_printf("  %p: buffer %u bytes\n",
                          entry->handle,
