@@ -56,32 +56,32 @@ svga_vbuf_render_get_vertex_info(struct vbuf_render *render)
 }
 
 
-static boolean
+static bool
 svga_vbuf_render_allocate_vertices(struct vbuf_render *render,
-                                   ushort vertex_size,
-                                   ushort nr_vertices)
+                                   uint16_t vertex_size,
+                                   uint16_t nr_vertices)
 {
    struct svga_vbuf_render *svga_render = svga_vbuf_render(render);
    struct svga_context *svga = svga_render->svga;
    struct pipe_screen *screen = svga->pipe.screen;
    size_t size = (size_t)nr_vertices * (size_t)vertex_size;
-   boolean new_vbuf = FALSE;
-   boolean new_ibuf = FALSE;
+   bool new_vbuf = false;
+   bool new_ibuf = false;
 
    SVGA_STATS_TIME_PUSH(svga_sws(svga),
                         SVGA_STATS_TIME_VBUFRENDERALLOCVERT);
 
    if (svga_render->vertex_size != vertex_size)
-      svga->swtnl.new_vdecl = TRUE;
+      svga->swtnl.new_vdecl = true;
    svga_render->vertex_size = (size_t)vertex_size;
 
    if (svga->swtnl.new_vbuf)
-      new_ibuf = new_vbuf = TRUE;
-   svga->swtnl.new_vbuf = FALSE;
+      new_ibuf = new_vbuf = true;
+   svga->swtnl.new_vbuf = false;
 
    if (svga_render->vbuf_size
        < svga_render->vbuf_offset + svga_render->vbuf_used + size)
-      new_vbuf = TRUE;
+      new_vbuf = true;
 
    if (new_vbuf)
       pipe_resource_reference(&svga_render->vbuf, NULL);
@@ -108,7 +108,7 @@ svga_vbuf_render_allocate_vertices(struct vbuf_render *render,
          svga_retry_exit(svga);
       }
 
-      svga->swtnl.new_vdecl = TRUE;
+      svga->swtnl.new_vdecl = true;
       svga_render->vbuf_offset = 0;
    } else {
       svga_render->vbuf_offset += svga_render->vbuf_used;
@@ -121,7 +121,7 @@ svga_vbuf_render_allocate_vertices(struct vbuf_render *render,
 
    SVGA_STATS_TIME_POP(svga_sws(svga));
 
-   return TRUE;
+   return true;
 }
 
 
@@ -165,8 +165,8 @@ svga_vbuf_render_map_vertices(struct vbuf_render *render)
 
 static void
 svga_vbuf_render_unmap_vertices(struct vbuf_render *render,
-                                ushort min_index,
-                                ushort max_index)
+                                uint16_t min_index,
+                                uint16_t max_index)
 {
    struct svga_vbuf_render *svga_render = svga_vbuf_render(render);
    struct svga_context *svga = svga_render->svga;
@@ -204,7 +204,7 @@ svga_vbuf_render_unmap_vertices(struct vbuf_render *render,
 
 static void
 svga_vbuf_render_set_primitive(struct vbuf_render *render,
-                               enum pipe_prim_type prim)
+                               enum mesa_prim prim)
 {
    struct svga_vbuf_render *svga_render = svga_vbuf_render(render);
    svga_render->prim = prim;
@@ -218,7 +218,7 @@ svga_vbuf_submit_state(struct svga_vbuf_render *svga_render)
    SVGA3dVertexDecl vdecl[PIPE_MAX_ATTRIBS];
    unsigned i;
    static const unsigned zero[PIPE_MAX_ATTRIBS] = {0};
-   boolean retried;
+   bool retried;
 
    /* if the vdecl or vbuf hasn't changed do nothing */
    if (!svga->swtnl.new_vdecl)
@@ -233,7 +233,7 @@ svga_vbuf_submit_state(struct svga_vbuf_render *svga_render)
    SVGA_RETRY_CHECK(svga, svga_hwtnl_flush(svga->hwtnl), retried);
    if (retried) {
       /* if we hit this path we might become synced with hw */
-      svga->swtnl.new_vbuf = TRUE;
+      svga->swtnl.new_vbuf = true;
    }
 
    for (i = 0; i < svga_render->vdecl_count; i++) {
@@ -252,7 +252,6 @@ svga_vbuf_submit_state(struct svga_vbuf_render *svga_render)
       vb.is_user_buffer = false;
       vb.buffer.resource = svga_render->vbuf;
       vb.buffer_offset = svga_render->vdecl_offset;
-      vb.stride = vdecl[0].array.stride;
       svga_hwtnl_vertex_buffers(svga->hwtnl, 1, &vb);
    }
 
@@ -260,7 +259,7 @@ svga_vbuf_submit_state(struct svga_vbuf_render *svga_render)
     * module use whatever is most convenient:
     */
    if (svga->state.sw.need_pipeline) {
-      svga_hwtnl_set_flatshade(svga->hwtnl, FALSE, FALSE);
+      svga_hwtnl_set_flatshade(svga->hwtnl, false, false);
       svga_hwtnl_set_fillmode(svga->hwtnl, PIPE_POLYGON_MODE_FILL);
    }
    else {
@@ -272,7 +271,7 @@ svga_vbuf_submit_state(struct svga_vbuf_render *svga_render)
       svga_hwtnl_set_fillmode(svga->hwtnl, svga->curr.rast->hw_fillmode);
    }
 
-   svga->swtnl.new_vdecl = FALSE;
+   svga->swtnl.new_vdecl = false;
    SVGA_STATS_TIME_POP(svga_sws(svga));
 }
 
@@ -288,7 +287,7 @@ svga_vbuf_render_draw_arrays(struct vbuf_render *render,
    /* instancing will already have been resolved at this point by 'draw' */
    const unsigned start_instance = 0;
    const unsigned instance_count = 1;
-   boolean retried;
+   bool retried;
 
    SVGA_STATS_TIME_PUSH(svga_sws(svga), SVGA_STATS_TIME_VBUFDRAWARRAYS);
 
@@ -304,7 +303,7 @@ svga_vbuf_render_draw_arrays(struct vbuf_render *render,
                     (svga->hwtnl, svga_render->prim, start + bias,
                      nr, start_instance, instance_count, 0), retried);
    if (retried) {
-      svga->swtnl.new_vbuf = TRUE;
+      svga->swtnl.new_vbuf = true;
    }
 
    SVGA_STATS_TIME_POP(svga_sws(svga));
@@ -313,14 +312,14 @@ svga_vbuf_render_draw_arrays(struct vbuf_render *render,
 
 static void
 svga_vbuf_render_draw_elements(struct vbuf_render *render,
-                                const ushort *indices,
+                                const uint16_t *indices,
                                 uint nr_indices)
 {
    struct svga_vbuf_render *svga_render = svga_vbuf_render(render);
    struct svga_context *svga = svga_render->svga;
    int bias = (svga_render->vbuf_offset - svga_render->vdecl_offset)
       / svga_render->vertex_size;
-   boolean retried;
+   bool retried;
    /* instancing will already have been resolved at this point by 'draw' */
    const struct pipe_draw_info info = {
       .index_size = 2,
@@ -356,7 +355,7 @@ svga_vbuf_render_draw_elements(struct vbuf_render *render,
                                                          &draw,
                                                          nr_indices), retried);
    if (retried) {
-      svga->swtnl.new_vbuf = TRUE;
+      svga->swtnl.new_vbuf = true;
    }
 
    SVGA_STATS_TIME_POP(svga_sws(svga));
