@@ -37,9 +37,9 @@
      _31,_32,_33,_34,_35,_36,_37,_38,_39,_40, \
      _41,_42,_43,_44,_45,_46,_47,_48,_49,_50, \
      _51,_52,_53,_54,_55,_56,_57,_58,_59,_60, \
-     _61,_62,_63,N,...) N
+     _61,_62,_63,_64,_65,_66,_67,_68,_69,_70,N,...) N
 #define __RSEQ_N() \
-     63,62,61,60,                   \
+     70,69,68,67,66,65,64,63,62,61,60, \
      59,58,57,56,55,54,53,52,51,50, \
      49,48,47,46,45,44,43,42,41,40, \
      39,38,37,36,35,34,33,32,31,30, \
@@ -60,6 +60,7 @@
 #define _args_for_bypass_56(a, b, c, d, e, f, g, ...) ,g _args_for_bypass_49(__VA_ARGS__)
 #define _args_for_bypass_63(a, b, c, d, e, f, g, ...) ,g _args_for_bypass_56(__VA_ARGS__)
 #define _args_for_bypass_70(a, b, c, d, e, f, g, ...) ,g _args_for_bypass_63(__VA_ARGS__)
+#define _args_for_bypass_77(a, b, c, d, e, f, g, ...) ,g _args_for_bypass_70(__VA_ARGS__)
 #else
 #define _args_for_bypass_14(a, b, c, d, e, f, g, ...) ,g __EXPAND_ARGS__(_args_for_bypass_7(__VA_ARGS__))
 #define _args_for_bypass_21(a, b, c, d, e, f, g, ...) ,g __EXPAND_ARGS__(_args_for_bypass_14(__VA_ARGS__))
@@ -70,6 +71,7 @@
 #define _args_for_bypass_56(a, b, c, d, e, f, g, ...) ,g __EXPAND_ARGS__(_args_for_bypass_49(__VA_ARGS__))
 #define _args_for_bypass_63(a, b, c, d, e, f, g, ...) ,g __EXPAND_ARGS__(_args_for_bypass_56(__VA_ARGS__))
 #define _args_for_bypass_70(a, b, c, d, e, f, g, ...) ,g __EXPAND_ARGS__(_args_for_bypass_63(__VA_ARGS__))
+#define _args_for_bypass_77(a, b, c, d, e, f, g, ...) ,g __EXPAND_ARGS__(_args_for_bypass_70(__VA_ARGS__))
 #endif
 
 #define _GFUNC_(n) _args_for_bypass_##n
@@ -93,6 +95,7 @@
 #define _args_for_mem_56(a, b, c, d, e, f, g, ...) f; _args_for_mem_49(__VA_ARGS__)
 #define _args_for_mem_63(a, b, c, d, e, f, g, ...) f; _args_for_mem_56(__VA_ARGS__)
 #define _args_for_mem_70(a, b, c, d, e, f, g, ...) f; _args_for_mem_63(__VA_ARGS__)
+#define _args_for_mem_77(a, b, c, d, e, f, g, ...) f; _args_for_mem_70(__VA_ARGS__)
 #else
 #define _args_for_mem_14(a, b, c, d, e, f, g, ...) f; __EXPAND_ARGS__(_args_for_mem_7(__VA_ARGS__))
 #define _args_for_mem_21(a, b, c, d, e, f, g, ...) f; __EXPAND_ARGS__(_args_for_mem_14(__VA_ARGS__))
@@ -103,6 +106,7 @@
 #define _args_for_mem_56(a, b, c, d, e, f, g, ...) f; __EXPAND_ARGS__(_args_for_mem_49(__VA_ARGS__))
 #define _args_for_mem_63(a, b, c, d, e, f, g, ...) f; __EXPAND_ARGS__(_args_for_mem_56(__VA_ARGS__))
 #define _args_for_mem_70(a, b, c, d, e, f, g, ...) f; __EXPAND_ARGS__(_args_for_mem_63(__VA_ARGS__))
+#define _args_for_mem_77(a, b, c, d, e, f, g, ...) f; __EXPAND_ARGS__(_args_for_mem_70(__VA_ARGS__))
 #endif
 
 #define _FFUNC_(n) _args_for_mem_##n
@@ -126,6 +130,7 @@
 #define _args_for_unbind_56(a, b, c, d, e, f, g, ...) e; _args_for_unbind_49(__VA_ARGS__)
 #define _args_for_unbind_63(a, b, c, d, e, f, g, ...) e; _args_for_unbind_56(__VA_ARGS__)
 #define _args_for_unbind_70(a, b, c, d, e, f, g, ...) e; _args_for_unbind_63(__VA_ARGS__)
+#define _args_for_unbind_77(a, b, c, d, e, f, g, ...) e; _args_for_unbind_70(__VA_ARGS__)
 #else
 #define _args_for_unbind_14(a, b, c, d, e, f, g, ...) e; __EXPAND_ARGS__(_args_for_unbind_7(__VA_ARGS__))
 #define _args_for_unbind_21(a, b, c, d, e, f, g, ...) e; __EXPAND_ARGS__(_args_for_unbind_14(__VA_ARGS__))
@@ -136,6 +141,7 @@
 #define _args_for_unbind_56(a, b, c, d, e, f, g, ...) e; __EXPAND_ARGS__(_args_for_unbind_49(__VA_ARGS__))
 #define _args_for_unbind_63(a, b, c, d, e, f, g, ...) e; __EXPAND_ARGS__(_args_for_unbind_56(__VA_ARGS__))
 #define _args_for_unbind_70(a, b, c, d, e, f, g, ...) e; __EXPAND_ARGS__(_args_for_unbind_63(__VA_ARGS__))
+#define _args_for_unbind_77(a, b, c, d, e, f, g, ...) e; __EXPAND_ARGS__(_args_for_unbind_70(__VA_ARGS__))
 #endif
 
 #define _EFUNC_(n) _args_for_unbind_##n
@@ -159,6 +165,7 @@
 #define _args_for_call_56(a, b, c, d, e, f, g, ...) ,d _args_for_call_49(__VA_ARGS__)
 #define _args_for_call_63(a, b, c, d, e, f, g, ...) ,d _args_for_call_56(__VA_ARGS__)
 #define _args_for_call_70(a, b, c, d, e, f, g, ...) ,d _args_for_call_63(__VA_ARGS__)
+#define _args_for_call_77(a, b, c, d, e, f, g, ...) ,d _args_for_call_70(__VA_ARGS__)
 #else
 #define _args_for_call_14(a, b, c, d, e, f, g, ...) ,d __EXPAND_ARGS__(_args_for_call_7(__VA_ARGS__))
 #define _args_for_call_21(a, b, c, d, e, f, g, ...) ,d __EXPAND_ARGS__(_args_for_call_14(__VA_ARGS__))
@@ -169,6 +176,7 @@
 #define _args_for_call_56(a, b, c, d, e, f, g, ...) ,d __EXPAND_ARGS__(_args_for_call_49(__VA_ARGS__))
 #define _args_for_call_63(a, b, c, d, e, f, g, ...) ,d __EXPAND_ARGS__(_args_for_call_56(__VA_ARGS__))
 #define _args_for_call_70(a, b, c, d, e, f, g, ...) ,d __EXPAND_ARGS__(_args_for_call_63(__VA_ARGS__))
+#define _args_for_call_77(a, b, c, d, e, f, g, ...) ,d __EXPAND_ARGS__(_args_for_call_70(__VA_ARGS__))
 #endif
 
 #define _DFUNC_(n) _args_for_call_##n
@@ -192,6 +200,7 @@
 #define _args_for_decl_56(a, b, c, d, e, f, g, ...) ,c _args_for_decl_49(__VA_ARGS__)
 #define _args_for_decl_63(a, b, c, d, e, f, g, ...) ,c _args_for_decl_56(__VA_ARGS__)
 #define _args_for_decl_70(a, b, c, d, e, f, g, ...) ,c _args_for_decl_63(__VA_ARGS__)
+#define _args_for_decl_77(a, b, c, d, e, f, g, ...) ,c _args_for_decl_70(__VA_ARGS__)
 #else
 #define _args_for_decl_14(a, b, c, d, e, f, g, ...) ,c __EXPAND_ARGS__(_args_for_decl_7(__VA_ARGS__))
 #define _args_for_decl_21(a, b, c, d, e, f, g, ...) ,c __EXPAND_ARGS__(_args_for_decl_14(__VA_ARGS__))
@@ -202,6 +211,7 @@
 #define _args_for_decl_56(a, b, c, d, e, f, g, ...) ,c __EXPAND_ARGS__(_args_for_decl_49(__VA_ARGS__))
 #define _args_for_decl_63(a, b, c, d, e, f, g, ...) ,c __EXPAND_ARGS__(_args_for_decl_56(__VA_ARGS__))
 #define _args_for_decl_70(a, b, c, d, e, f, g, ...) ,c __EXPAND_ARGS__(_args_for_decl_63(__VA_ARGS__))
+#define _args_for_decl_77(a, b, c, d, e, f, g, ...) ,c __EXPAND_ARGS__(_args_for_decl_70(__VA_ARGS__))
 #endif
 
 #define _CFUNC_(n) _args_for_decl_##n
@@ -225,6 +235,7 @@
 #define _args_for_assign_56(a, b, c, d, e, f, g, ...) b; _args_for_assign_49(__VA_ARGS__)
 #define _args_for_assign_63(a, b, c, d, e, f, g, ...) b; _args_for_assign_56(__VA_ARGS__)
 #define _args_for_assign_70(a, b, c, d, e, f, g, ...) b; _args_for_assign_63(__VA_ARGS__)
+#define _args_for_assign_77(a, b, c, d, e, f, g, ...) b; _args_for_assign_70(__VA_ARGS__)
 #else
 #define _args_for_assign_14(a, b, c, d, e, f, g, ...) b; __EXPAND_ARGS__(_args_for_assign_7(__VA_ARGS__))
 #define _args_for_assign_21(a, b, c, d, e, f, g, ...) b; __EXPAND_ARGS__(_args_for_assign_14(__VA_ARGS__))
@@ -235,6 +246,7 @@
 #define _args_for_assign_56(a, b, c, d, e, f, g, ...) b; __EXPAND_ARGS__(_args_for_assign_49(__VA_ARGS__))
 #define _args_for_assign_63(a, b, c, d, e, f, g, ...) b; __EXPAND_ARGS__(_args_for_assign_56(__VA_ARGS__))
 #define _args_for_assign_70(a, b, c, d, e, f, g, ...) b; __EXPAND_ARGS__(_args_for_assign_63(__VA_ARGS__))
+#define _args_for_assign_77(a, b, c, d, e, f, g, ...) b; __EXPAND_ARGS__(_args_for_assign_70(__VA_ARGS__))
 #endif
 
 #define _BFUNC_(n) _args_for_assign_##n
@@ -258,6 +270,7 @@
 #define _args_for_struct_56(a, b, c, d, e, f, g, ...) a; _args_for_struct_49(__VA_ARGS__)
 #define _args_for_struct_63(a, b, c, d, e, f, g, ...) a; _args_for_struct_56(__VA_ARGS__)
 #define _args_for_struct_70(a, b, c, d, e, f, g, ...) a; _args_for_struct_63(__VA_ARGS__)
+#define _args_for_struct_77(a, b, c, d, e, f, g, ...) a; _args_for_struct_70(__VA_ARGS__)
 #else
 #define _args_for_struct_14(a, b, c, d, e, f, g, ...) a; __EXPAND_ARGS__(_args_for_struct_7(__VA_ARGS__))
 #define _args_for_struct_21(a, b, c, d, e, f, g, ...) a; __EXPAND_ARGS__(_args_for_struct_14(__VA_ARGS__))
@@ -268,6 +281,7 @@
 #define _args_for_struct_56(a, b, c, d, e, f, g, ...) a; __EXPAND_ARGS__(_args_for_struct_49(__VA_ARGS__))
 #define _args_for_struct_63(a, b, c, d, e, f, g, ...) a; __EXPAND_ARGS__(_args_for_struct_56(__VA_ARGS__))
 #define _args_for_struct_70(a, b, c, d, e, f, g, ...) a; __EXPAND_ARGS__(_args_for_struct_63(__VA_ARGS__))
+#define _args_for_struct_77(a, b, c, d, e, f, g, ...) a; __EXPAND_ARGS__(_args_for_struct_70(__VA_ARGS__))
 #endif
 
 #define _AFUNC_(n) _args_for_struct_##n
@@ -427,7 +441,7 @@ name( struct NineDevice9 *device ARGS_FOR_DECLARATION( __VA_ARGS__ ) ) \
     assert(args); \
     args->instr.func = &name##_rx; \
     ARGS_FOR_ASSIGN( __VA_ARGS__ ) \
-    ctx->processed = FALSE; \
+    ctx->processed = false; \
     nine_queue_flush(ctx->pool); \
     nine_csmt_wait_processed(ctx); \
 } \
