@@ -27,10 +27,20 @@
 
 #include <stdbool.h>
 
+struct pipe_resource;
 struct pipe_screen;
+struct pipe_screen_config;
 struct renderonly;
+struct renderonly_scanout;
+struct winsys_handle;
 
 struct pipe_screen *panfrost_drm_screen_create(int drmFD);
-struct pipe_screen *panfrost_drm_screen_create_renderonly(struct renderonly *ro);
+struct pipe_screen *
+panfrost_drm_screen_create_renderonly(int fd, struct renderonly *ro,
+                                      const struct pipe_screen_config *config);
+struct renderonly_scanout *
+panfrost_create_kms_dumb_buffer_for_resource(struct pipe_resource *rsc,
+                                             struct renderonly *ro,
+                                             struct winsys_handle *out_handle);
 
 #endif /* __PAN_DRM_PUBLIC_H__ */
