@@ -31,7 +31,7 @@
 
 #include <inttypes.h>  /* for PRIx64 macro */
 
-#include "main/glheader.h"
+#include "util/glheader.h"
 #include "main/context.h"
 
 #include "prog_instruction.h"
@@ -51,8 +51,6 @@ _mesa_register_file_name(gl_register_file f)
    switch (f) {
    case PROGRAM_TEMPORARY:
       return "TEMP";
-   case PROGRAM_ARRAY:
-      return "ARRAY";
    case PROGRAM_INPUT:
       return "INPUT";
    case PROGRAM_OUTPUT:
@@ -65,22 +63,10 @@ _mesa_register_file_name(gl_register_file f)
       return "UNIFORM";
    case PROGRAM_ADDRESS:
       return "ADDR";
-   case PROGRAM_SAMPLER:
-      return "SAMPLER";
    case PROGRAM_SYSTEM_VALUE:
       return "SYSVAL";
    case PROGRAM_UNDEFINED:
       return "UNDEFINED";
-   case PROGRAM_IMMEDIATE:
-      return "IMM";
-   case PROGRAM_BUFFER:
-      return "BUFFER";
-   case PROGRAM_MEMORY:
-      return "MEMORY";
-   case PROGRAM_IMAGE:
-      return "IMAGE";
-   case PROGRAM_HW_ATOMIC:
-      return "HWATOMIC";
    default:
       {
          static char s[20];
@@ -387,41 +373,78 @@ reg_string(gl_register_file f, GLint index, gl_prog_print_mode mode,
 
    switch (mode) {
    case PROG_PRINT_DEBUG:
-      snprintf(str, sizeof(str), "%s[%s%d]",                /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+      sprintf(str, "%s[%s%d]",
               _mesa_register_file_name(f), addr, index);
+#else
+      snprintf(str, sizeof(str), "%s[%s%d]",
+              _mesa_register_file_name(f), addr, index);
+#endif
       break;
 
    case PROG_PRINT_ARB:
       switch (f) {
       case PROGRAM_INPUT:
-         snprintf(str, sizeof(str), "%s", arb_input_attrib_string(index, prog->Target));     /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+         sprintf(str, "%s", arb_input_attrib_string(index, prog->Target));
+#else
+         snprintf(str, sizeof(str), "%s", arb_input_attrib_string(index, prog->Target));
+#endif
          break;
       case PROGRAM_OUTPUT:
-         snprintf(str, sizeof(str), "%s", arb_output_attrib_string(index, prog->Target));    /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+         sprintf(str, "%s", arb_output_attrib_string(index, prog->Target));
+#else
+         snprintf(str, sizeof(str), "%s", arb_output_attrib_string(index, prog->Target));
+#endif
          break;
       case PROGRAM_TEMPORARY:
-         snprintf(str, sizeof(str), "temp%d", index);                                        /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+         sprintf(str, "temp%d", index);
+#else
+         snprintf(str, sizeof(str), "temp%d", index);
+#endif
          break;
       case PROGRAM_CONSTANT: /* extension */
-         snprintf(str, sizeof(str), "constant[%s%d]", addr, index);                          /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+         sprintf(str, "constant[%s%d]", addr, index);
+#else
+         snprintf(str, sizeof(str), "constant[%s%d]", addr, index);
+#endif
          break;
       case PROGRAM_UNIFORM: /* extension */
-         snprintf(str, sizeof(str), "uniform[%s%d]", addr, index);                           /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+         sprintf(str, "uniform[%s%d]", addr, index);
+#else
+         snprintf(str, sizeof(str), "uniform[%s%d]", addr, index);
+#endif
          break;
       case PROGRAM_SYSTEM_VALUE:
-         snprintf(str, sizeof(str), "sysvalue[%s%d]", addr, index);                          /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+         sprintf(str, "sysvalue[%s%d]", addr, index);
+#else
+         snprintf(str, sizeof(str), "sysvalue[%s%d]", addr, index);
+#endif
          break;
       case PROGRAM_STATE_VAR:
          {
             struct gl_program_parameter *param
                = prog->Parameters->Parameters + index;
             char *state = _mesa_program_state_string(param->StateIndexes);
-            snprintf(str, sizeof(str), "%s", state);                                         /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+            sprintf(str, "%s", state);
+#else
+            snprintf(str, sizeof(str), "%s", state);
+#endif
             free(state);
          }
          break;
       case PROGRAM_ADDRESS:
-         snprintf(str, sizeof(str), "A%d", index);                                           /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+         sprintf(str, "A%d", index);
+#else
+         snprintf(str, sizeof(str), "A%d", index);
+#endif
          break;
       default:
          _mesa_problem(NULL, "bad file in reg_string()");
@@ -624,12 +647,6 @@ _mesa_fprint_instruction_opt(FILE *f,
 {
    GLint i;
 
-   if (inst->Opcode == OPCODE_ELSE ||
-       inst->Opcode == OPCODE_ENDIF ||
-       inst->Opcode == OPCODE_ENDLOOP ||
-       inst->Opcode == OPCODE_ENDSUB) {
-      indent -= 3;
-   }
    for (i = 0; i < indent; i++) {
       fprintf(f, " ");
    }
@@ -696,51 +713,6 @@ _mesa_fprint_instruction_opt(FILE *f,
       fprint_src_reg(f, &inst->SrcReg[0], mode, prog);
       fprintf(f, ";\n");
       break;
-   case OPCODE_IF:
-      fprintf(f, "IF ");
-      fprint_src_reg(f, &inst->SrcReg[0], mode, prog);
-      fprintf(f, "; ");
-      fprintf(f, " # (if false, goto %d)", inst->BranchTarget);
-      fprintf(f, ";\n");
-      return indent + 3;
-   case OPCODE_ELSE:
-      fprintf(f, "ELSE; # (goto %d)\n", inst->BranchTarget);
-      return indent + 3;
-   case OPCODE_ENDIF:
-      fprintf(f, "ENDIF;\n");
-      break;
-   case OPCODE_BGNLOOP:
-      fprintf(f, "BGNLOOP; # (end at %d)\n", inst->BranchTarget);
-      return indent + 3;
-   case OPCODE_ENDLOOP:
-      fprintf(f, "ENDLOOP; # (goto %d)\n", inst->BranchTarget);
-      break;
-   case OPCODE_BRK:
-   case OPCODE_CONT:
-      fprintf(f, "%s; # (goto %d)",
-	      _mesa_opcode_string(inst->Opcode),
-	      inst->BranchTarget);
-      fprintf(f, ";\n");
-      break;
-
-   case OPCODE_BGNSUB:
-      fprintf(f, "BGNSUB");
-      fprintf(f, ";\n");
-      return indent + 3;
-   case OPCODE_ENDSUB:
-      if (mode == PROG_PRINT_DEBUG) {
-         fprintf(f, "ENDSUB");
-         fprintf(f, ";\n");
-      }
-      break;
-   case OPCODE_CAL:
-      fprintf(f, "CAL %u", inst->BranchTarget);
-      fprintf(f, ";\n");
-      break;
-   case OPCODE_RET:
-      fprintf(f, "RET");
-      fprintf(f, ";\n");
-      break;
 
    case OPCODE_END:
       fprintf(f, "END\n");
@@ -997,11 +969,7 @@ _mesa_write_shader_to_file(const struct gl_shader *shader)
       return;
    }
 
-#ifdef DEBUG
-   fprintf(f, "/* Shader %u source, checksum %u */\n", shader->Name, shader->SourceChecksum);
-#else
    fprintf(f, "/* Shader %u source */\n", shader->Name);
-#endif
    fputs(shader->Source, f);
    fprintf(f, "\n");
 
