@@ -31,12 +31,11 @@
 
 #include <stdio.h>
 #include <stddef.h>
-#include "main/glheader.h"
+#include "util/glheader.h"
 #include "main/context.h"
 #include "main/blend.h"
 
 #include "main/macros.h"
-#include "main/mtypes.h"
 #include "main/fbobject.h"
 #include "prog_statevars.h"
 #include "prog_parameter.h"
@@ -309,12 +308,22 @@ fetch_state(struct gl_context *ctx, const gl_state_index16 state[],
       else
          COPY_4V(value, ctx->Fog.ColorUnclamped);
       return;
-   case STATE_FOG_PARAMS:
+   case STATE_FOG_PARAMS: {
+      float scale = 1.0f / (ctx->Fog.End - ctx->Fog.Start);
+      /* Pass +-FLT_MAX/2 to the shader instead of +-Inf because Infs have
+       * undefined behavior without GLSL 4.10 or GL_ARB_shader_precision
+       * enabled. Infs also have undefined behavior with Shader Model 3.
+       *
+       * The division by 2 makes it less likely that ALU ops will generate
+       * Inf.
+       */
+      scale = CLAMP(scale, FLT_MIN / 2, FLT_MAX / 2);
       value[0] = ctx->Fog.Density;
       value[1] = ctx->Fog.Start;
       value[2] = ctx->Fog.End;
-      value[3] = 1.0f / (ctx->Fog.End - ctx->Fog.Start);
+      value[3] = scale;
       return;
+   }
    case STATE_CLIPPLANE:
       {
          const GLuint plane = (GLuint) state[1];
@@ -780,6 +789,13 @@ fetch_state(struct gl_context *ctx, const gl_state_index16 state[],
          COPY_4V(value, ctx->Transform._ClipUserPlane[plane]);
       }
       return;
+
+   case STATE_ATOMIC_COUNTER_OFFSET:
+      {
+         const GLuint counter = (GLuint) state[1];
+         val[0].i = ctx->AtomicBufferBindings[counter].Offset % ctx->Const.ShaderStorageBufferOffsetAlignment;
+      }
+      return;
    }
 }
 
@@ -913,6 +929,10 @@ _mesa_program_state_flags(const gl_state_index16 state[STATE_LENGTH])
    case STATE_CLIP_INTERNAL:
       return _NEW_TRANSFORM | _NEW_PROJECTION;
 
+   /* Needs to return any nonzero value to trigger constant updating */
+   case STATE_ATOMIC_COUNTER_OFFSET:
+      return _NEW_PROGRAM_CONSTANTS;
+
    case STATE_TCS_PATCH_VERTICES_IN:
    case STATE_TES_PATCH_VERTICES_IN:
    case STATE_INTERNAL_DRIVER:
@@ -1193,6 +1213,9 @@ append_token(char *dst, gl_state_index k)
    case STATE_CLIP_INTERNAL:
       append(dst, "clipInternal");
       break;
+   case STATE_ATOMIC_COUNTER_OFFSET:
+      append(dst, "counterOffset");
+      break;
    default:
       /* probably STATE_INTERNAL_DRIVER+i (driver private state) */
       append(dst, "driverState");
@@ -1203,7 +1226,11 @@ static void
 append_index(char *dst, GLint index, bool structure)
 {
    char s[20];
-   snprintf(s, sizeof(s), "[%d]%s", index, structure ? "." : ""); /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+   sprintf(s, "[%d]%s", index, structure ? "." : "");
+#else
+   snprintf(s, sizeof(s), "[%d]%s", index, structure ? "." : "");
+#endif
    append(dst, s);
 }
 
@@ -1286,9 +1313,17 @@ _mesa_program_state_string(const gl_state_index16 state[STATE_LENGTH])
               mat <= STATE_PROGRAM_MATRIX_INVTRANS))
             append_index(str, index, true);
          if (firstRow == lastRow)
-            snprintf(tmp, sizeof(tmp), "row[%d]", firstRow);                        /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+            sprintf(tmp, "row[%d]", firstRow);
+#else
+            snprintf(tmp, sizeof(tmp), "row[%d]", firstRow);
+#endif
          else
-            snprintf(tmp, sizeof(tmp), "row[%d..%d]", firstRow, lastRow);           /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+            sprintf(tmp, "row[%d..%d]", firstRow, lastRow);
+#else
+            snprintf(tmp, sizeof(tmp), "row[%d..%d]", firstRow, lastRow);
+#endif
          append(str, tmp);
       }
       break;
@@ -1303,7 +1338,11 @@ _mesa_program_state_string(const gl_state_index16 state[STATE_LENGTH])
    case STATE_LIGHTPROD_ARRAY_TWOSIDE:
    case STATE_LIGHT_POSITION_ARRAY:
    case STATE_LIGHT_POSITION_NORMALIZED_ARRAY:
-      snprintf(tmp, sizeof(tmp), "[%d..%d]", state[1], state[1] + state[2] - 1);    /* VBox: sprintf -> snprintf */
+#ifndef IPRT_NO_CRT
+      sprintf(tmp, "[%d..%d]", state[1], state[1] + state[2] - 1);
+#else
+      snprintf(tmp, sizeof(tmp), "[%d..%d]", state[1], state[1] + state[2] - 1);
+#endif
       append(str, tmp);
       break;
    case STATE_MATERIAL:
@@ -1318,6 +1357,7 @@ _mesa_program_state_string(const gl_state_index16 state[STATE_LENGTH])
    case STATE_LIGHT_POSITION_NORMALIZED:
    case STATE_LIGHT_HALF_VECTOR:
    case STATE_CLIP_INTERNAL:
+   case STATE_ATOMIC_COUNTER_OFFSET:
       append_index(str, state[1], false);
       break;
    case STATE_POINT_SIZE:
@@ -1334,6 +1374,7 @@ _mesa_program_state_string(const gl_state_index16 state[STATE_LENGTH])
    case STATE_PT_BIAS:
    case STATE_FB_SIZE:
    case STATE_FB_WPOS_Y_TRANSFORM:
+   case STATE_FB_PNTC_Y_TRANSFORM:
    case STATE_TCS_PATCH_VERTICES_IN:
    case STATE_TES_PATCH_VERTICES_IN:
    case STATE_ADVANCED_BLENDING_MODE:
@@ -1343,7 +1384,7 @@ _mesa_program_state_string(const gl_state_index16 state[STATE_LENGTH])
       append(str, "not_state");
       break;
    default:
-      _mesa_problem(NULL, "Invalid state in _mesa_program_state_string");
+      _mesa_problem(NULL, "Invalid state in _mesa_program_state_string: %d", state[0]);
       break;
    }
 
@@ -1592,22 +1633,28 @@ _mesa_optimize_state_parameters(struct gl_constants *consts,
          gl_state_index16 state = STATE_NOT_STATE_VAR;
          unsigned num_lights = 0;
 
-         for (unsigned state_iter = STATE_LIGHTPROD_ARRAY_FRONT;
+         for (gl_state_index state_iter = STATE_LIGHTPROD_ARRAY_FRONT;
               state_iter <= STATE_LIGHTPROD_ARRAY_TWOSIDE; state_iter++) {
             unsigned num_attribs, base_attrib, attrib_incr;
 
-            if (state_iter == STATE_LIGHTPROD_ARRAY_FRONT)  {
+            switch (state_iter) {
+            case STATE_LIGHTPROD_ARRAY_FRONT:
                num_attribs = 3;
                base_attrib = MAT_ATTRIB_FRONT_AMBIENT;
                attrib_incr = 2;
-            } else if (state_iter == STATE_LIGHTPROD_ARRAY_BACK) {
+               break;
+            case STATE_LIGHTPROD_ARRAY_BACK:
                num_attribs = 3;
                base_attrib = MAT_ATTRIB_BACK_AMBIENT;
                attrib_incr = 2;
-            } else if (state_iter == STATE_LIGHTPROD_ARRAY_TWOSIDE) {
+               break;
+            case STATE_LIGHTPROD_ARRAY_TWOSIDE:
                num_attribs = 6;
                base_attrib = MAT_ATTRIB_FRONT_AMBIENT;
                attrib_incr = 1;
+               break;
+            default:
+               unreachable("unexpected state-var");
             }
 
             /* Find all attributes for one light. */
