@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2011-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2011-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -320,193 +320,6 @@ static DDSURFACEDESC gVBoxSurfDescsBase[] = {
         },
 };
 
-#ifdef VBOX_WITH_VIDEOHWACCEL
-
-static void vboxVhwaPopulateOverlayFourccSurfDesc(DDSURFACEDESC *pDesc, uint32_t fourcc)
-{
-    memset(pDesc, 0, sizeof (DDSURFACEDESC));
-
-    pDesc->dwSize = sizeof (DDSURFACEDESC);
-    pDesc->dwFlags = DDSD_CAPS | DDSD_PIXELFORMAT;
-    pDesc->ddpfPixelFormat.dwSize = sizeof (DDPIXELFORMAT);
-    pDesc->ddpfPixelFormat.dwFlags = DDPF_FOURCC;
-    pDesc->ddpfPixelFormat.dwFourCC = fourcc;
-    pDesc->ddsCaps.dwCaps = DDSCAPS_BACKBUFFER
-            | DDSCAPS_COMPLEX
-            | DDSCAPS_FLIP
-            | DDSCAPS_FRONTBUFFER
-            | DDSCAPS_LOCALVIDMEM
-            | DDSCAPS_OVERLAY
-            | DDSCAPS_VIDEOMEMORY
-            | DDSCAPS_VISIBLE;
-}
-
-static bool vboxPixFormatMatch(DDPIXELFORMAT *pFormat1, DDPIXELFORMAT *pFormat2)
-{
-    return !memcmp(pFormat1, pFormat2, sizeof (DDPIXELFORMAT));
-}
-
-HRESULT vboxSurfDescMerge(DDSURFACEDESC *paDescs, uint32_t *pcDescs, uint32_t cMaxDescs, DDSURFACEDESC *pDesc)
-{
-    uint32_t cDescs = *pcDescs;
-
-    Assert(cMaxDescs >= cDescs);
-    Assert(pDesc->dwFlags == (DDSD_CAPS | DDSD_PIXELFORMAT));
-    if (pDesc->dwFlags != (DDSD_CAPS | DDSD_PIXELFORMAT))
-        return E_INVALIDARG;
-
-    for (uint32_t i = 0; i < cDescs; ++i)
-    {
-        DDSURFACEDESC *pCur = &paDescs[i];
-        if (vboxPixFormatMatch(&pCur->ddpfPixelFormat, &pDesc->ddpfPixelFormat))
-        {
-            if (pDesc->dwFlags & DDSD_CAPS)
-            {
-                pCur->dwFlags |= DDSD_CAPS;
-                pCur->ddsCaps.dwCaps |= pDesc->ddsCaps.dwCaps;
-            }
-            return S_OK;
-        }
-    }
-
-    if (cMaxDescs > cDescs)
-    {
-        paDescs[cDescs] = *pDesc;
-        ++cDescs;
-        *pcDescs = cDescs;
-        return VINF_SUCCESS;
-    }
-    return E_FAIL;
-}
-
-HRESULT vboxFormatOpsMerge(FORMATOP *paOps, uint32_t *pcOps, uint32_t cMaxOps, FORMATOP *pOp)
-{
-    uint32_t cOps = *pcOps;
-
-    Assert(cMaxOps >= cOps);
-
-    for (uint32_t i = 0; i < cOps; ++i)
-    {
-        FORMATOP *pCur = &paOps[i];
-        if (pCur->Format == pOp->Format)
-        {
-            pCur->Operations |= pOp->Operations;
-            Assert(pCur->FlipMsTypes == pOp->FlipMsTypes);
-            Assert(pCur->BltMsTypes == pOp->BltMsTypes);
-            Assert(pCur->PrivateFormatBitCount == pOp->PrivateFormatBitCount);
-            return S_OK;
-        }
-    }
-
-    if (cMaxOps > cOps)
-    {
-        paOps[cOps] = *pOp;
-        ++cOps;
-        *pcOps = cOps;
-        return VINF_SUCCESS;
-    }
-    return E_FAIL;
-}
-
-HRESULT VBoxDispD3DGlobal2DFormatsInit(PVBOXWDDMDISP_ADAPTER pAdapter)
-{
-    HRESULT hr = S_OK;
-    memset(&pAdapter->D3D, 0, sizeof (pAdapter->D3D));
-    memset(&pAdapter->Formats, 0, sizeof (pAdapter->Formats));
-
-    /* just calc the max number of formats */
-    uint32_t cFormats = RT_ELEMENTS(gVBoxFormatOpsBase);
-    uint32_t cSurfDescs = RT_ELEMENTS(gVBoxSurfDescsBase);
-    uint32_t cOverlayFormats = 0;
-    for (uint32_t i = 0; i < pAdapter->cHeads; ++i)
-    {
-        VBOXDISPVHWA_INFO *pVhwa = &pAdapter->aHeads[i].Vhwa;
-        if (pVhwa->Settings.fFlags & VBOXVHWA_F_ENABLED)
-        {
-            cOverlayFormats += pVhwa->Settings.cFormats;
-        }
-    }
-
-    cFormats += cOverlayFormats;
-    cSurfDescs += cOverlayFormats;
-
-    uint32_t cbFormatOps = cFormats * sizeof (FORMATOP);
-    cbFormatOps = (cbFormatOps + 7) & ~3;
-    /* ensure the surf descs are 8 byte aligned */
-    uint32_t offSurfDescs = (cbFormatOps + 7) & ~3;
-    uint32_t cbSurfDescs = cSurfDescs * sizeof (DDSURFACEDESC);
-    uint32_t cbBuf = offSurfDescs + cbSurfDescs;
-    uint8_t* pvBuf = (uint8_t*)RTMemAllocZ(cbBuf);
-    if (pvBuf)
-    {
-        pAdapter->Formats.paFormatOps = (FORMATOP*)pvBuf;
-        memcpy ((void*)pAdapter->Formats.paFormatOps , gVBoxFormatOpsBase, sizeof (gVBoxFormatOpsBase));
-        pAdapter->Formats.cFormatOps = RT_ELEMENTS(gVBoxFormatOpsBase);
-
-        FORMATOP fo = {D3DDDIFMT_UNKNOWN, 0, 0, 0, 0};
-        for (uint32_t i = 0; i < pAdapter->cHeads; ++i)
-        {
-            VBOXDISPVHWA_INFO *pVhwa = &pAdapter->aHeads[i].Vhwa;
-            if (pVhwa->Settings.fFlags & VBOXVHWA_F_ENABLED)
-            {
-                for (uint32_t j = 0; j < pVhwa->Settings.cFormats; ++j)
-                {
-                    fo.Format = pVhwa->Settings.aFormats[j];
-                    fo.Operations = FORMATOP_OVERLAY;
-                    hr = vboxFormatOpsMerge((FORMATOP *)pAdapter->Formats.paFormatOps, &pAdapter->Formats.cFormatOps, cFormats, &fo);
-                    if (FAILED(hr))
-                    {
-                        WARN(("vboxFormatOpsMerge failed, hr 0x%x", hr));
-                    }
-                }
-            }
-        }
-
-        pAdapter->Formats.paSurfDescs = (DDSURFACEDESC*)(pvBuf + offSurfDescs);
-        memcpy ((void*)pAdapter->Formats.paSurfDescs , gVBoxSurfDescsBase, sizeof (gVBoxSurfDescsBase));
-        pAdapter->Formats.cSurfDescs = RT_ELEMENTS(gVBoxSurfDescsBase);
-
-        DDSURFACEDESC sd;
-        for (uint32_t i = 0; i < pAdapter->cHeads; ++i)
-        {
-            VBOXDISPVHWA_INFO *pVhwa = &pAdapter->aHeads[i].Vhwa;
-            if (pVhwa->Settings.fFlags & VBOXVHWA_F_ENABLED)
-            {
-                for (uint32_t j = 0; j < pVhwa->Settings.cFormats; ++j)
-                {
-                    uint32_t fourcc = vboxWddmFormatToFourcc(pVhwa->Settings.aFormats[j]);
-                    if (fourcc)
-                    {
-                        vboxVhwaPopulateOverlayFourccSurfDesc(&sd, fourcc);
-                        hr = vboxSurfDescMerge((DDSURFACEDESC *)pAdapter->Formats.paSurfDescs, &pAdapter->Formats.cSurfDescs, cSurfDescs, &sd);
-                        if (FAILED(hr))
-                        {
-                            WARN(("vboxFormatOpsMerge failed, hr 0x%x", hr));
-                        }
-                    }
-                }
-            }
-        }
-    }
-    else
-    {
-        WARN(("RTMemAllocZ failed"));
-        return E_FAIL;
-    }
-    return S_OK;
-}
-
-void VBoxDispD3DGlobal2DFormatsTerm(PVBOXWDDMDISP_ADAPTER pAdapter)
-{
-    if (pAdapter->Formats.paFormatOps)
-    {
-        RTMemFree((void *)pAdapter->Formats.paFormatOps);
-        pAdapter->Formats.paFormatOps = NULL;
-    }
-}
-
-#endif
-
 static CRITICAL_SECTION g_VBoxDispD3DGlobalCritSect;
 static VBOXWDDMDISP_D3D g_VBoxDispD3DGlobalD3D;
 static VBOXWDDMDISP_FORMATS g_VBoxDispD3DGlobalD3DFormats;
