@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2006-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2006-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -81,8 +81,8 @@ static int vboxTrayGlMsgTaskbarCreated(WPARAM lParam, LPARAM wParam);
 /*********************************************************************************************************************************
 *   Structures and Typedefs                                                                                                      *
 *********************************************************************************************************************************/
-typedef BOOL (WINAPI *PFNALLOCCONSOLE)(VOID);
-typedef BOOL (WINAPI *PFNATTACHCONSOLE)(DWORD);
+typedef BOOL (WINAPI *PFNALLOCCONSOLE)(VOID)   RT_NOEXCEPT;
+typedef BOOL (WINAPI *PFNATTACHCONSOLE)(DWORD) RT_NOEXCEPT;
 
 
 /*********************************************************************************************************************************
@@ -1467,7 +1467,7 @@ static LRESULT CALLBACK vboxToolWndProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPA
 
         case WM_DISPLAYCHANGE:
             ASMAtomicUoWriteU32(&g_fGuestDisplaysChanged, 1);
-            // No break or return is intentional here.
+            RT_FALL_THROUGH();
         case WM_VBOX_SEAMLESS_UPDATE:
         {
             if (VBoxCapsEntryIsEnabled(VBOXCAPS_ENTRY_IDX_SEAMLESS))
@@ -1518,3 +1518,4 @@ static void VBoxGrapicsSetSupported(BOOL fSupported)
 {
     VBoxConsoleCapSetSupported(VBOXCAPS_ENTRY_IDX_GRAPHICS, fSupported);
 }
+
