@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2009-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2009-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -1849,7 +1849,7 @@ static DECLCALLBACK(int) vbsvcVMInfoWorker(bool volatile *pfShutdown)
             /* Reset event semaphore if it got triggered. */
             rc2 = RTSemEventMultiReset(g_hVMInfoEvent);
             if (RT_FAILURE(rc2))
-                rc2 = VGSvcError("RTSemEventMultiReset failed; rc2=%Rrc\n", rc2);
+                VGSvcError("RTSemEventMultiReset failed; rc2=%Rrc\n", rc2);
         }
     }
 
@@ -1891,7 +1891,7 @@ static DECLCALLBACK(void) vbsvcVMInfoTerm(void)
          *        since it remembers what we've written. */
         /* Delete the "../Net" branch. */
         const char *apszPat[1] = { "/VirtualBox/GuestInfo/Net/*" };
-        int rc = VbglR3GuestPropDelSet(g_uVMInfoGuestPropSvcClientID, &apszPat[0], RT_ELEMENTS(apszPat));
+        VbglR3GuestPropDelSet(g_uVMInfoGuestPropSvcClientID, &apszPat[0], RT_ELEMENTS(apszPat));
 
         /* Destroy LA client info. */
         vgsvcFreeLAClientInfo(&g_LAClientInfo);
@@ -1900,9 +1900,7 @@ static DECLCALLBACK(void) vbsvcVMInfoTerm(void)
         VGSvcPropCacheDestroy(&g_VMInfoPropCache);
 
         /* Disconnect from guest properties service. */
-        rc = VbglR3GuestPropDisconnect(g_uVMInfoGuestPropSvcClientID);
-        if (RT_FAILURE(rc))
-            VGSvcError("Failed to disconnect from guest property service! Error: %Rrc\n", rc);
+        VbglR3GuestPropDisconnect(g_uVMInfoGuestPropSvcClientID);
         g_uVMInfoGuestPropSvcClientID = 0;
 
         RTSemEventMultiDestroy(g_hVMInfoEvent);
