@@ -1,3 +1,5 @@
+/* $TOG: panoramiX.h /main/4 1998/03/17 06:51:02 kaleb $ */
+/* $XdotOrg: xc/programs/Xserver/Xext/panoramiX.h,v 1.3 2005/04/20 12:25:12 daniels Exp $ */
 /*****************************************************************
 
 Copyright (c) 1991, 1997 Digital Equipment Corporation, Maynard, Massachusetts.
@@ -26,6 +28,7 @@ Equipment Corporation.
 
 ******************************************************************/
 
+/* $XFree86: xc/programs/Xserver/Xext/panoramiX.h,v 1.5 2001/01/03 02:54:17 keithp Exp $ */
 
 /* THIS IS NOT AN X PROJECT TEAM SPECIFICATION */
 
@@ -40,10 +43,7 @@ Equipment Corporation.
 #ifndef _PANORAMIX_H_
 #define _PANORAMIX_H_
 
-#define _PANORAMIX_SERVER
 #include <X11/extensions/panoramiXext.h>
-#undef _PANORAMIX_SERVER
-
 #include "gcstruct.h"
 
 
@@ -96,6 +96,18 @@ typedef struct {
     (a).root = WindowTable[0]->drawable.id;          \
 }
 
+#define FORCE_WIN(a) {                                  \
+    if ((win = PanoramiXFindIDOnAnyScreen(XRT_WINDOW, a))) { \
+        (a) = win->info[0].id; /* Real ID */       	   \
+    }                                                      \
+}
+
+#define FORCE_CMAP(a) {                                  \
+    if ((win = PanoramiXFindIDOnAnyScreen(XRT_COLORMAP, a))) { \
+        (a) = win->info[0].id; /* Real ID */       	   \
+    }                                                      \
+}
+
 #define IS_SHARED_PIXMAP(r) (((r)->type == XRT_PIXMAP) && (r)->u.pix.shared)
 
 #define SKIP_FAKE_WINDOW(a) if(!LookupIDByType(a, XRT_WINDOW)) return
