@@ -1,3 +1,5 @@
+/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86Module.h,v 1.37 2003/08/24 17:36:54 dawes Exp $ */
+
 /*
  * Copyright (c) 1997-2003 by The XFree86 Project, Inc.
  *
@@ -42,6 +44,7 @@
 #define _XF86MODULE_H
 
 #include "misc.h"
+#include "xf86Version.h"
 #ifndef NULL
 #define NULL ((void *)0)
 #endif
@@ -81,17 +84,21 @@ typedef enum {
  * changed.  The minor revision mask is 0x0000FFFF and the major revision
  * mask is 0xFFFF0000.
  */
-#define ABI_ANSIC_VERSION	SET_ABI_VERSION(0, 4)
-#define ABI_VIDEODRV_VERSION	SET_ABI_VERSION(8, 0)
-#define ABI_XINPUT_VERSION	SET_ABI_VERSION(11, 0)
-#define ABI_EXTENSION_VERSION	SET_ABI_VERSION(4, 0)
-#define ABI_FONT_VERSION	SET_ABI_VERSION(0, 6)
+#define ABI_ANSIC_VERSION	SET_ABI_VERSION(0, 2)
+#define ABI_VIDEODRV_VERSION	SET_ABI_VERSION(0, 8)
+#define ABI_XINPUT_VERSION	SET_ABI_VERSION(0, 5)
+#define ABI_EXTENSION_VERSION	SET_ABI_VERSION(0, 2)
+#define ABI_FONT_VERSION	SET_ABI_VERSION(0, 4)
 
 #define MODINFOSTRING1	0xef23fdc5
 #define MODINFOSTRING2	0x10dc023a
 
 #ifndef MODULEVENDORSTRING
+#ifndef __OS2ELF__
 #define MODULEVENDORSTRING	"X.Org Foundation"
+#else
+#define MODULEVENDORSTRING	"X.Org Foundation - OS2"
+#endif
 #endif
 
 /* Error return codes for errmaj.  New codes must only be added at the end. */
@@ -181,22 +188,29 @@ typedef struct {
     const char **	initDependencies;
 } ExtensionModule;
 
-extern _X_EXPORT ExtensionModule *ExtensionModuleList;
+extern ExtensionModule *ExtensionModuleList;
 
 /* Prototypes for Loader functions that are exported to modules */
-extern _X_EXPORT pointer LoadSubModule(pointer, const char *, const char **,
+#ifndef IN_LOADER
+/* Prototypes with opaque pointers for use by modules */
+pointer LoadSubModule(pointer, const char *, const char **,
 		      const char **, pointer, const XF86ModReqInfo *,
 		      int *, int *);
-extern _X_EXPORT void UnloadSubModule(pointer);
-extern _X_EXPORT void UnloadModule (pointer);
-extern _X_EXPORT pointer LoaderSymbol(const char *);
-extern _X_EXPORT char **LoaderListDirs(const char **, const char **);
-extern _X_EXPORT void LoaderFreeDirList(char **);
-extern _X_EXPORT void LoaderErrorMsg(const char *, const char *, int, int);
-extern _X_EXPORT void LoadExtension(ExtensionModule *, Bool);
-extern _X_EXPORT void LoaderGetOS(const char **name, int *major, int *minor, int *teeny);
-extern _X_EXPORT Bool LoaderShouldIgnoreABI(void);
-extern _X_EXPORT int LoaderGetABIVersion(const char *abiclass);
+void UnloadSubModule(pointer);
+void LoadFont(pointer);
+void UnloadModule (pointer);
+#endif
+pointer LoaderSymbol(const char *);
+char **LoaderListDirs(const char **, const char **);
+void LoaderFreeDirList(char **);
+void LoaderErrorMsg(const char *, const char *, int, int);
+void LoadExtension(ExtensionModule *, Bool);
+void LoaderRefSymLists(const char **, ...);
+void LoaderRefSymbols(const char *, ...);
+void LoaderReqSymLists(const char **, ...);
+void LoaderReqSymbols(const char *, ...);
+int LoaderCheckUnresolved(int);
+void LoaderGetOS(const char **name, int *major, int *minor, int *teeny);
 
 typedef pointer (*ModuleSetupProc)(pointer, pointer, int *, int *);
 typedef void (*ModuleTearDownProc)(pointer);
