@@ -1,3 +1,4 @@
+/* $Xorg: mipoly.h,v 1.4 2001/02/09 02:05:21 xorgcvs Exp $ */
 /*
 
 Copyright 1987, 1998  The Open Group
@@ -25,6 +26,7 @@ other dealings in this Software without prior written authorization
 from The Open Group.
 
 */
+/* $XFree86: xc/programs/Xserver/mi/mipoly.h,v 1.2 2001/08/06 20:51:19 dawes Exp $ */
 
 
 /*
@@ -180,7 +182,15 @@ typedef struct _ScanLineListBlock {
 
 /* mipolyutil.c */
 
-extern _X_EXPORT Bool miCreateETandAET(
+extern Bool miInsertEdgeInET(
+    EdgeTable * /*ET*/,
+    EdgeTableEntry * /*ETE*/,
+    int /*scanline*/,
+    ScanLineListBlock ** /*SLLBlock*/,
+    int * /*iSLLBlock*/
+);
+
+extern Bool miCreateETandAET(
     int /*count*/,
     DDXPointPtr /*pts*/,
     EdgeTable * /*ET*/,
@@ -189,19 +199,19 @@ extern _X_EXPORT Bool miCreateETandAET(
     ScanLineListBlock * /*pSLLBlock*/
 );
 
-extern _X_EXPORT void miloadAET(
+extern void miloadAET(
     EdgeTableEntry * /*AET*/,
     EdgeTableEntry * /*ETEs*/
 );
 
-extern _X_EXPORT void micomputeWAET(
+extern void micomputeWAET(
     EdgeTableEntry * /*AET*/
 );
 
-extern _X_EXPORT int miInsertionSort(
+extern int miInsertionSort(
     EdgeTableEntry * /*AET*/
 );
 
-extern _X_EXPORT void miFreeStorage(
+extern void miFreeStorage(
     ScanLineListBlock * /*pSLLBlock*/
 );
