@@ -76,7 +76,7 @@ extern int ChangeDeviceNotify;
 extern int DevicePresenceNotify;
 extern int DevicePropertyNotify;
 
-extern RESTYPE RT_INPUTCLIENT;
+extern int RT_INPUTCLIENT;
 
 extern DevPrivateKeyRec XIClientPrivateKeyRec;
 #define XIClientPrivateKey (&XIClientPrivateKeyRec)
