@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/Xi/ungrdev.h,v 3.1 1996/04/15 11:19:08 dawes Exp $ */
 /************************************************************
 
 Copyright 1996 by Thomas E. Dickey <dickey@clark.net>
@@ -31,14 +30,10 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #ifndef UNGRDEV_H
 #define UNGRDEV_H 1
 
-int
-SProcXUngrabDevice(
-	ClientPtr /* client */
-	);
+int SProcXUngrabDevice(ClientPtr	/* client */
+    );
 
-int
-ProcXUngrabDevice(
-	ClientPtr /* client */
-	);
+int ProcXUngrabDevice(ClientPtr	/* client */
+    );
 
 #endif /* UNGRDEV_H */
