@@ -61,6 +61,7 @@ typedef enum { ClientStateInitial,
     ClientStateGone
 } ClientState;
 
+#ifdef XFIXES
 typedef struct _saveSet {
     struct _Window *windowPtr;
     Bool toRoot;
@@ -72,10 +73,20 @@ typedef struct _saveSet {
 #define SaveSetAssignWindow(ss,w)   ((ss).windowPtr = (w))
 #define SaveSetAssignToRoot(ss,tr)  ((ss).toRoot = (tr))
 #define SaveSetAssignMap(ss,m)      ((ss).map = (m))
+#else
+typedef struct _Window *SaveSetElt;
+
+#define SaveSetWindow(ss)   (ss)
+#define SaveSetToRoot(ss)   FALSE
+#define SaveSetShouldMap(ss)	    TRUE
+#define SaveSetAssignWindow(ss,w)   ((ss) = (w))
+#define SaveSetAssignToRoot(ss,tr)
+#define SaveSetAssignMap(ss,m)
+#endif
 
 typedef struct _Client {
-    void *requestBuffer;
-    void *osPrivate;             /* for OS layer, including scheduler */
+    pointer requestBuffer;
+    pointer osPrivate;          /* for OS layer, including scheduler */
     Mask clientAsMask;
     short index;
     unsigned char majorOp, minorOp;
@@ -85,7 +96,7 @@ typedef struct _Client {
     unsigned int clientGone:1;
     unsigned int closeDownMode:2;
     unsigned int clientState:2;
-    signed char smart_priority;
+    char smart_priority;
     short noClientException;      /* this client died or needs to be killed */
     int priority;
     ReplySwapPtr pSwapReplyFunc;
@@ -106,23 +117,12 @@ typedef struct _Client {
 
     int smart_start_tick;
     int smart_stop_tick;
+    int smart_check_tick;
 
     DeviceIntPtr clientPtr;
     ClientIdPtr clientIds;
-#if XTRANS_SEND_FDS
-    int req_fds;
-#endif
 } ClientRec;
 
-#if XTRANS_SEND_FDS
-static inline void
-SetReqFds(ClientPtr client, int req_fds) {
-    if (client->req_fds != 0 && req_fds != client->req_fds)
-        LogMessage(X_ERROR, "Mismatching number of request fds %d != %d\n", req_fds, client->req_fds);
-    client->req_fds = req_fds;
-}
-#endif
-
 /*
  * Scheduling interface
  */
@@ -148,13 +148,14 @@ SmartScheduleInit(void);
 typedef struct _WorkQueue {
     struct _WorkQueue *next;
     Bool (*function) (ClientPtr /* pClient */ ,
-                      void *    /* closure */
+                      pointer   /* closure */
         );
     ClientPtr client;
-    void *closure;
+    pointer closure;
 } WorkQueueRec;
 
 extern _X_EXPORT TimeStamp currentTime;
+extern _X_EXPORT TimeStamp lastDeviceEventTime[MAXDEVICES];
 
 extern _X_EXPORT int
 CompareTimeStamps(TimeStamp /*a */ ,
@@ -165,7 +166,7 @@ ClientTimeToServerTime(CARD32 /*c */ );
 
 typedef struct _CallbackRec {
     CallbackProcPtr proc;
-    void *data;
+    pointer data;
     Bool deleted;
     struct _CallbackRec *next;
 } CallbackRec, *CallbackPtr;
