@@ -26,13 +26,13 @@ Copyright 1987 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
-Permission to use, copy, modify, and distribute this software and its
-documentation for any purpose and without fee is hereby granted,
+Permission to use, copy, modify, and distribute this software and its 
+documentation for any purpose and without fee is hereby granted, 
 provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in
+both that copyright notice and this permission notice appear in 
 supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
-software without specific, written prior permission.
+software without specific, written prior permission.  
 
 DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
 ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
@@ -43,7 +43,7 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 Copyright 1992, 1993 Data General Corporation;
-Copyright 1992, 1993 OMRON Corporation
+Copyright 1992, 1993 OMRON Corporation  
 
 Permission to use, copy, modify, distribute, and sell this software and its
 documentation for any purpose is hereby granted without fee, provided that the
@@ -51,9 +51,9 @@ above copyright notice appear in all copies and that both that copyright
 notice and this permission notice appear in supporting documentation, and that
 neither the name OMRON or DATA GENERAL be used in advertising or publicity
 pertaining to distribution of the software without specific, written prior
-permission of the party whose name is to be used.  Neither OMRON or
+permission of the party whose name is to be used.  Neither OMRON or 
 DATA GENERAL make any representation about the suitability of this software
-for any purpose.  It is provided "as is" without express or implied warranty.
+for any purpose.  It is provided "as is" without express or implied warranty.  
 
 OMRON AND DATA GENERAL EACH DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -67,7 +67,7 @@ OF THIS SOFTWARE.
 #ifndef MISC_H
 #define MISC_H 1
 /*
- *  X internal definitions
+ *  X internal definitions 
  *
  */
 
@@ -138,7 +138,7 @@ lswapl(uint32_t x)
 static inline uint16_t
 lswaps(uint16_t x)
 {
-    return (uint16_t)((x & 0xff) << 8) | ((x >> 8) & 0xff);
+    return ((x & 0xff) << 8) | ((x >> 8) & 0xff);
 }
 
 #undef min
@@ -259,19 +259,15 @@ extern void FormatDouble(double dbl, char *string);
  * or a value greater than 0
  */
 static inline int
-version_compare(uint32_t a_major, uint32_t a_minor,
-                uint32_t b_major, uint32_t b_minor)
+version_compare(uint16_t a_major, uint16_t a_minor,
+                uint16_t b_major, uint16_t b_minor)
 {
-    if (a_major > b_major)
-        return 1;
-    if (a_major < b_major)
-        return -1;
-    if (a_minor > b_minor)
-        return 1;
-    if (a_minor < b_minor)
-        return -1;
+    int a, b;
 
-    return 0;
+    a = a_major << 16 | a_minor;
+    b = b_major << 16 | b_minor;
+
+    return (a - b);
 }
 
 /* some macros to help swap requests, replies, and events */
@@ -309,35 +305,6 @@ __builtin_constant_p(int x)
 }
 #endif
 
-/* byte swap a 64-bit value */
-static inline void
-swap_uint64(uint64_t *x)
-{
-    char n;
-
-    n = ((char *) x)[0];
-    ((char *) x)[0] = ((char *) x)[7];
-    ((char *) x)[7] = n;
-
-    n = ((char *) x)[1];
-    ((char *) x)[1] = ((char *) x)[6];
-    ((char *) x)[6] = n;
-
-    n = ((char *) x)[2];
-    ((char *) x)[2] = ((char *) x)[5];
-    ((char *) x)[5] = n;
-
-    n = ((char *) x)[3];
-    ((char *) x)[3] = ((char *) x)[4];
-    ((char *) x)[4] = n;
-}
-
-#define swapll(x) do { \
-		if (sizeof(*(x)) != 8) \
-			wrong_size(); \
-                swap_uint64((uint64_t *)(x));   \
-	} while (0)
-
 /* byte swap a 32-bit value */
 static inline void
 swap_uint32(uint32_t * x)
