@@ -22,7 +22,6 @@ Except as contained in this notice, the name of The Open Group shall not be
 used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
-
 Copyright 1987 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
@@ -46,46 +45,41 @@ SOFTWARE.
 ******************************************************************/
 
 #ifndef PROPERTY_H
-#define PROPERTY_H 
+#define PROPERTY_H
 
 #include "window.h"
 
 typedef struct _Property *PropertyPtr;
 
-extern int dixLookupProperty(
-    PropertyPtr * /*result*/,
-    WindowPtr /*pWin*/,
-    Atom /*proprty*/,
-    ClientPtr /*pClient*/,
-    Mask /*access_mode*/);
+extern _X_EXPORT int dixLookupProperty(PropertyPtr * /*result */ ,
+                                       WindowPtr /*pWin */ ,
+                                       Atom /*proprty */ ,
+                                       ClientPtr /*pClient */ ,
+                                       Mask /*access_mode */ );
 
-extern int dixChangeWindowProperty(
-    ClientPtr /*pClient*/,
-    WindowPtr /*pWin*/,
-    Atom /*property*/,
-    Atom /*type*/,
-    int /*format*/,
-    int /*mode*/,
-    unsigned long /*len*/,
-    pointer /*value*/,
-    Bool /*sendevent*/);
+extern _X_EXPORT int dixChangeWindowProperty(ClientPtr /*pClient */ ,
+                                             WindowPtr /*pWin */ ,
+                                             Atom /*property */ ,
+                                             Atom /*type */ ,
+                                             int /*format */ ,
+                                             int /*mode */ ,
+                                             unsigned long /*len */ ,
+                                             void */*value */ ,
+                                             Bool /*sendevent */ );
 
-extern int ChangeWindowProperty(
-    WindowPtr /*pWin*/,
-    Atom /*property*/,
-    Atom /*type*/,
-    int /*format*/,
-    int /*mode*/,
-    unsigned long /*len*/,
-    pointer /*value*/,
-    Bool /*sendevent*/);
+extern _X_EXPORT int ChangeWindowProperty(WindowPtr /*pWin */ ,
+                                          Atom /*property */ ,
+                                          Atom /*type */ ,
+                                          int /*format */ ,
+                                          int /*mode */ ,
+                                          unsigned long /*len */ ,
+                                          void */*value */ ,
+                                          Bool /*sendevent */ );
 
-extern int DeleteProperty(
-    ClientPtr /*client*/,
-    WindowPtr /*pWin*/,
-    Atom /*propName*/);
+extern _X_EXPORT int DeleteProperty(ClientPtr /*client */ ,
+                                    WindowPtr /*pWin */ ,
+                                    Atom /*propName */ );
 
-extern void DeleteAllWindowProperties(
-    WindowPtr /*pWin*/);
+extern _X_EXPORT void DeleteAllWindowProperties(WindowPtr /*pWin */ );
 
-#endif  /* PROPERTY_H */
+#endif                          /* PROPERTY_H */
