@@ -1,3 +1,7 @@
+#ifdef HAVE_DIX_CONFIG_H
+#include <dix-config.h>
+#endif
+
 #ifndef _GLX_screens_h_
 #define _GLX_screens_h_
 
@@ -36,27 +40,60 @@
 **
 */
 
+/* XXX: should be defined somewhere globally */
+#define CAPI
+
 #include "GL/internal/glcore.h"
 
+/*
+** Screen dependent data.  These methods are the interface between the DIX
+** and DDX layers of the GLX server extension.  The methods provide an
+** interface for context management on a screen.
+*/
+typedef struct __GLXscreen __GLXscreen;
+struct __GLXscreen {
+    void          (*destroy)       (__GLXscreen *screen);
 
+    __GLXcontext *(*createContext) (__GLXscreen *screen,
+				    __GLcontextModes *modes,
+				    __GLXcontext *shareContext);
 
-typedef struct {
+    __GLXdrawable *(*createDrawable)(__GLXscreen *context,
+				     DrawablePtr pDraw,
+				     XID drawId,
+				     __GLcontextModes *modes);
+    int            (*swapInterval)  (__GLXdrawable *drawable,
+				     int interval);
 
-    __GLXvisualConfig *pGlxVisual;
+    ScreenPtr pScreen;
+
+    /**
+     * Linked list of valid context modes for this screen.
+     */
+    __GLcontextModes *modes;
+
+    void **pVisualPriv;
     GLint numVisuals;
-    GLint numGLXVisuals;
-    GLint *isGLXvis;
+    GLint numUsableVisuals;
+
+    char *GLextensions;
 
     char *GLXvendor;
     char *GLXversion;
     char *GLXextensions;
 
-} __GLXscreenInfo;
+    /*
+    ** Things that are not statically set.
+    */
+    Bool (*WrappedPositionWindow)(WindowPtr pWin, int x, int y);
+
+};
 
 
-extern void __glXScreenInit(GLint);
-extern void __glXScreenReset(void);
+void __glXScreenInit(__GLXscreen *screen, ScreenPtr pScreen);
+void __glXScreenDestroy(__GLXscreen *screen);
 
-extern char *__glXGetServerString( unsigned int name );
+void __glXInitScreens(void);
+extern void __glXResetScreens(void);
 
 #endif /* !__GLX_screens_h__ */
