@@ -35,8 +35,6 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #ifndef _DRI_H_
 
-#include <pciaccess.h>
-
 #include "scrnintstr.h"
 #include "xf86dri.h"
 
@@ -365,7 +363,7 @@ extern void DRIMoveBuffersHelper(ScreenPtr pScreen,
                                  int *ydir, 
                                  RegionPtr reg);
 
-extern char *DRICreatePCIBusID(const struct pci_device *PciInfo);
+extern char *DRICreatePCIBusID(pciVideoPtr PciInfo);
 
 extern int drmInstallSIGIOHandler(int fd, void (*f)(int, void *, void *));
 extern int drmRemoveSIGIOHandler(int fd);
