@@ -87,10 +87,12 @@ typedef struct _DMXLocalInitInfo {
     KeySymsRec           keySyms;  /**< Key symbols */
     int                  freemap;  /**< If non-zero, free keySyms.map */
     CARD8                modMap[MAP_LENGTH]; /**< Modifier map */
+#ifdef XKB
     XkbDescPtr           xkb;       /**< XKB description */
     XkbComponentNamesRec names;     /**< XKB component names */
     int                  freenames; /**< Non-zero if names should be free'd */
     int                  force;     /**< Do not allow command line override */
+#endif
 
     int                  buttonClass; /**< Non-zero if buttons are present */
     int                  numButtons;  /**< Number of buttons */
@@ -276,8 +278,8 @@ extern void dmxKeyboardKbdCtrlProc(DeviceIntPtr pDevice, KeybdCtrl *ctrl);
 extern void dmxKeyboardBellProc(int percent, DeviceIntPtr pDevice,
                                 pointer ctrl, int unknown);
 
-extern int  dmxInputExtensionErrorHandler(Display *dsp, _Xconst char *name,
-                                          _Xconst char *reason);
+extern int  dmxInputExtensionErrorHandler(Display *dsp, char *name,
+                                          char *reason);
 
 extern int          dmxInputDetach(DMXInputInfo *dmxInput);
 extern void         dmxInputDetachAll(DMXScreenInfo *dmxScreen);
