@@ -26,15 +26,12 @@
  * holders shall not be used in advertising or otherwise to promote the sale,
  * use or other dealings in this Software without prior written authorization.
  */
-/* $XFree86: xc/programs/Xserver/miext/rootless/safeAlpha/safeAlpha.h,v 1.2 2003/10/18 00:00:34 torrey Exp $ */
 
 #ifndef _SAFEALPHA_H
 #define _SAFEALPHA_H
 
 #include "picturestr.h"
 
-void SafeAlphaPaintWindow(WindowPtr pWin, RegionPtr pRegion, int what);
-
 #ifdef RENDER
 void
 SafeAlphaComposite(CARD8 op, PicturePtr pSrc, PicturePtr pMask, PicturePtr pDst,
