@@ -37,37 +37,34 @@
 #include "windowstr.h"
 #include "selection.h"
 #include "scrnintstr.h"
-#include "damage.h"
+#include "damageext.h"
+#include "damage.h" 
 #include "xfixes.h"
 
 typedef struct _DamageClient {
-    CARD32 major_version;
-    CARD32 minor_version;
-    int critical;
+    CARD32	major_version;
+    CARD32	minor_version;
+    int		critical;
 } DamageClientRec, *DamageClientPtr;
 
 #define GetDamageClient(pClient) ((DamageClientPtr)dixLookupPrivate(&(pClient)->devPrivates, DamageClientPrivateKey))
 
 typedef struct _DamageExt {
-    DamagePtr pDamage;
-    DrawablePtr pDrawable;
-    DamageReportLevel level;
-    ClientPtr pClient;
-    XID id;
-    XID drawable;
+    DamagePtr		pDamage;
+    DrawablePtr		pDrawable;
+    DamageReportLevel	level;
+    ClientPtr		pClient;
+    XID			id;
 } DamageExtRec, *DamageExtPtr;
 
 #define VERIFY_DAMAGEEXT(pDamageExt, rid, client, mode) { \
     int rc = dixLookupResourceByType((pointer *)&(pDamageExt), rid, \
                                      DamageExtType, client, mode); \
     if (rc != Success) \
-        return rc; \
+        return (rc == BadValue) ? DamageErrorBase + BadDamage : rc; \
 }
 
 void
- DamageExtSetCritical(ClientPtr pClient, Bool critical);
+DamageExtSetCritical (ClientPtr pClient, Bool critical);
 
-void PanoramiXDamageInit(void);
-void PanoramiXDamageReset(void);
-
-#endif                          /* _DAMAGEEXTINT_H_ */
+#endif /* _DAMAGEEXTINT_H_ */
