@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2020-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2020-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -87,6 +87,8 @@
 /*********************************************************************************************************************************
 *   Defined Constants And Macros                                                                                                 *
 *********************************************************************************************************************************/
+/** Saved state version for the device. */
+#define QEMU_FW_CFG_SAVED_STATE_VERSION             1
 
 /** Start of the I/O port region. */
 #define QEMU_FW_CFG_IO_PORT_START                   0x510
@@ -211,6 +213,26 @@ typedef const QEMURAMFBCONFIG *PCQEMURAMFBCONFIG;
 #define QEMU_RAMFB_CFG_BPP               4
 
 
+/**
+ * RAM based framebuffer data.
+ */
+typedef struct QEMURAMFB
+{
+    /** Number of entries in the page mapping lock array. */
+    uint32_t                    cPgLocks;
+    /** Pointer to the PGM page mapping lock array. */
+    PPGMPAGEMAPLOCK             paPgLocks;
+    /** Pointer to the array of page pointers. */
+    const void                  **papvPages;
+    /** Pointer to the final segments. */
+    PRTSGSEG                    paSegs;
+    /** S/G buffer. */
+    RTSGBUF                     SgBuf;
+} QEMURAMFB;
+/** Pointer to the RAM based framebuffer data. */
+typedef QEMURAMFB *PQEMURAMFB;
+
+
 /**
  * QEMU firmware config DMA descriptor.
  */
@@ -406,6 +428,8 @@ typedef struct DEVQEMUFWCFG
     TMTIMERHANDLE                       hRamfbRefreshTimer;
     /** The current rambuffer config if enabled. */
     QEMURAMFBCONFIG                     RamfbCfg;
+    /** The RAM based framebuffer data. */
+    QEMURAMFB                           Ramfb;
     /** Flag whether rendering the VRAM is enabled currently. */
     bool                                fRenderVRam;
     /** Flag whether the RAM based framebuffer device is enabled. */
@@ -1166,6 +1190,108 @@ static DECLCALLBACK(VBOXSTRICTRC) qemuFwCfgMmioWrite(PPDMDEVINS pDevIns, void *p
 }
 
 
+
+/* -=-=-=-=-=-=-=-=- Saved State -=-=-=-=-=-=-=-=- */
+
+/**
+ * @callback_method_impl{FNSSMDEVLIVEEXEC}
+ */
+static DECLCALLBACK(int) qemuFwCfgR3LiveExec(PPDMDEVINS pDevIns, PSSMHANDLE pSSM, uint32_t uPass)
+{
+    PDEVQEMUFWCFG pThis = PDMDEVINS_2_DATA(pDevIns, PDEVQEMUFWCFG);
+    PCPDMDEVHLPR3 pHlp  = pDevIns->pHlpR3;
+    RT_NOREF(uPass);
+
+    pHlp->pfnSSMPutBool(pSSM, pThis->fRamfbSupported);
+    return VINF_SSM_DONT_CALL_AGAIN;
+}
+
+
+/**
+ * @callback_method_impl{FNSSMDEVSAVEEXEC}
+ */
+static DECLCALLBACK(int) qemuFwCfgR3SaveExec(PPDMDEVINS pDevIns, PSSMHANDLE pSSM)
+{
+    PDEVQEMUFWCFG pThis = PDMDEVINS_2_DATA(pDevIns, PDEVQEMUFWCFG);
+    PCPDMDEVHLPR3 pHlp  = pDevIns->pHlpR3;
+
+    /* The config. */
+    qemuFwCfgR3LiveExec(pDevIns, pSSM, SSM_PASS_FINAL);
+
+    /* The state. */
+    pHlp->pfnSSMPutGCPhys(pSSM, pThis->RamfbCfg.GCPhysRamfbBase);
+    pHlp->pfnSSMPutU32(   pSSM, pThis->RamfbCfg.cbStride);
+    pHlp->pfnSSMPutU32(   pSSM, pThis->RamfbCfg.cWidth);
+    pHlp->pfnSSMPutU32(   pSSM, pThis->RamfbCfg.cHeight);
+    pHlp->pfnSSMPutU32(   pSSM, pThis->RamfbCfg.u32FourCC);
+    pHlp->pfnSSMPutU32(   pSSM, pThis->RamfbCfg.u32Flags);
+
+    return pHlp->pfnSSMPutU32(pSSM, UINT32_MAX); /* sanity/terminator */
+}
+
+
+/**
+ * @callback_method_impl{FNSSMDEVLOADEXEC}
+ */
+static DECLCALLBACK(int) qemuFwCfgR3LoadExec(PPDMDEVINS pDevIns, PSSMHANDLE pSSM, uint32_t uVersion, uint32_t uPass)
+{
+    PDEVQEMUFWCFG pThis = PDMDEVINS_2_DATA(pDevIns, PDEVQEMUFWCFG);
+    PCPDMDEVHLPR3 pHlp  = pDevIns->pHlpR3;
+    int rc;
+
+    if (uVersion != QEMU_FW_CFG_SAVED_STATE_VERSION)
+        return VERR_SSM_UNSUPPORTED_DATA_UNIT_VERSION;
+
+    /* The config. */
+    bool fRamfbSupported;
+    rc = pHlp->pfnSSMGetBool(pSSM, &fRamfbSupported);
+    AssertRCReturn(rc, rc);
+    if (fRamfbSupported != pThis->fRamfbSupported)
+        return pHlp->pfnSSMSetCfgError(pSSM, RT_SRC_POS, N_("Config mismatch - fRamfbSupported: saved=%RTbool config=%RTbool"),
+                                                            fRamfbSupported, pThis->fRamfbSupported);
+
+    if (uPass != SSM_PASS_FINAL)
+        return VINF_SUCCESS;
+
+    pHlp->pfnSSMGetGCPhys(pSSM, &pThis->RamfbCfg.GCPhysRamfbBase);
+    pHlp->pfnSSMGetU32(   pSSM, &pThis->RamfbCfg.cbStride);
+    pHlp->pfnSSMGetU32(   pSSM, &pThis->RamfbCfg.cWidth);
+    pHlp->pfnSSMGetU32(   pSSM, &pThis->RamfbCfg.cHeight);
+    pHlp->pfnSSMGetU32(   pSSM, &pThis->RamfbCfg.u32FourCC);
+    pHlp->pfnSSMGetU32(   pSSM, &pThis->RamfbCfg.u32Flags);
+
+    /* The marker. */
+    uint32_t u32;
+    rc = pHlp->pfnSSMGetU32(pSSM, &u32);
+    AssertRCReturn(rc, rc);
+    AssertMsgReturn(u32 == UINT32_MAX, ("%#x\n", u32), VERR_SSM_DATA_UNIT_FORMAT_CHANGED);
+
+    return VINF_SUCCESS;
+}
+
+
+/**
+ * @callback_method_impl{FNSSMDEVLOADDONE}
+ */
+static DECLCALLBACK(int) qemuFwCfgR3LoadDone(PPDMDEVINS pDevIns, PSSMHANDLE pSSM)
+{
+    PDEVQEMUFWCFG pThis = PDMDEVINS_2_DATA(pDevIns, PDEVQEMUFWCFG);
+    RT_NOREF(pSSM);
+
+    if (   pThis->pDrvL0
+        && pThis->RamfbCfg.GCPhysRamfbBase)
+    {
+        int rc = pThis->pDrvL0->pfnResize(pThis->pDrvL0, QEMU_RAMFB_CFG_BPP * 8, NULL /*pvVRAM*/,
+                                          pThis->RamfbCfg.cbStride,
+                                          pThis->RamfbCfg.cWidth,
+                                          pThis->RamfbCfg.cHeight);
+        AssertRC(rc);
+    }
+
+    return VINF_SUCCESS;
+}
+
+
 /**
  * Sets up the initrd memory file and CPIO filesystem stream for writing.
  *
@@ -1377,6 +1503,9 @@ static int qemuFwCfgInitrdArchiveDirSub(RTVFSFSSTREAM hVfsFss,
                 break;
             }
         }
+
+        if (RT_FAILURE(rc))
+            break;
     }
 
     if (rc == VERR_NO_MORE_FILES)
@@ -1569,6 +1698,16 @@ static DECLCALLBACK(int) qemuFwCfgR3RamfbCfgWrite(PDEVQEMUFWCFG pThis, PCQEMUFWC
     int const rcLock = PDMDevHlpCritSectEnter(pThis->pDevIns, &pThis->CritSectRamfb, VERR_SEM_BUSY);
     PDM_CRITSECT_RELEASE_ASSERT_RC_DEV(pThis->pDevIns, &pThis->CritSectRamfb, rcLock);
 
+    if (pThis->Ramfb.cPgLocks)
+    {
+        PDMDevHlpPhysBulkReleasePageMappingLocks(pThis->pDevIns, pThis->Ramfb.cPgLocks, pThis->Ramfb.paPgLocks);
+        RTMemFree(pThis->Ramfb.paPgLocks);
+        pThis->Ramfb.paPgLocks = NULL;
+        pThis->Ramfb.papvPages = NULL;
+        pThis->Ramfb.paSegs    = NULL;
+        pThis->Ramfb.cPgLocks  = 0;
+    }
+
     pThis->RamfbCfg.GCPhysRamfbBase = RT_BE2H_U64(pRamfbCfg->GCPhysRamfbBase);
     pThis->RamfbCfg.cbStride        = RT_BE2H_U32(pRamfbCfg->cbStride);
     pThis->RamfbCfg.cWidth          = RT_BE2H_U32(pRamfbCfg->cWidth);
@@ -1599,11 +1738,12 @@ static DECLCALLBACK(int) qemuFwCfgR3RamfbCfgWrite(PDEVQEMUFWCFG pThis, PCQEMUFWC
 static DECLCALLBACK(int) qemuFwCfgR3RamfbPortUpdateDisplay(PPDMIDISPLAYPORT pInterface)
 {
     PDEVQEMUFWCFG pThis = RT_FROM_MEMBER(pInterface, DEVQEMUFWCFG, IPortRamfb);
+    PPDMDEVINS pDevIns = pThis->pDevIns;
 
     LogFlowFunc(("\n"));
 
-    int const rcLock = PDMDevHlpCritSectEnter(pThis->pDevIns, &pThis->CritSectRamfb, VERR_SEM_BUSY);
-    PDM_CRITSECT_RELEASE_ASSERT_RC_DEV(pThis->pDevIns, &pThis->CritSectRamfb, rcLock);
+    int const rcLock = PDMDevHlpCritSectEnter(pDevIns, &pThis->CritSectRamfb, VERR_SEM_BUSY);
+    PDM_CRITSECT_RELEASE_ASSERT_RC_DEV(pDevIns, &pThis->CritSectRamfb, rcLock);
 
     if (   pThis->fRenderVRam
         && pThis->RamfbCfg.GCPhysRamfbBase)
@@ -1613,7 +1753,72 @@ static DECLCALLBACK(int) qemuFwCfgR3RamfbPortUpdateDisplay(PPDMIDISPLAYPORT pInt
             && pThis->RamfbCfg.cbStride == pThis->pDrvL0->cbScanline
             && pThis->pDrvL0->pbData)
         {
-            PDMDevHlpPhysReadUser(pThis->pDevIns, pThis->RamfbCfg.GCPhysRamfbBase, pThis->pDrvL0->pbData, pThis->RamfbCfg.cbStride * pThis->RamfbCfg.cHeight);
+            /* Try map the pages. */
+            if (RT_UNLIKELY(!pThis->Ramfb.cPgLocks))
+            {
+                size_t const cbFb = pThis->RamfbCfg.cbStride * pThis->RamfbCfg.cHeight;
+                uint32_t const cPages = (uint32_t)((cbFb + GUEST_PAGE_SIZE - 1) >> GUEST_PAGE_SHIFT);
+                RTGCPHYS GCPhysStart = pThis->RamfbCfg.GCPhysRamfbBase & ~(RTGCPHYS)GUEST_PAGE_OFFSET_MASK;
+                RTGCPHYS const offPage = pThis->RamfbCfg.GCPhysRamfbBase & (RTGCPHYS)GUEST_PAGE_OFFSET_MASK;
+
+                pThis->Ramfb.paPgLocks = (PPGMPAGEMAPLOCK)RTMemAllocZ(cPages * (  sizeof(PGMPAGEMAPLOCK)
+                                                                                + sizeof(void *)
+                                                                                + sizeof(RTGCPHYS)
+                                                                                + sizeof(RTSGSEG)));
+                if (!pThis->Ramfb.paPgLocks)
+                    return VERR_NO_MEMORY;
+
+                pThis->Ramfb.cPgLocks  = cPages;
+                pThis->Ramfb.papvPages = (const void **)&pThis->Ramfb.paPgLocks[cPages];
+                pThis->Ramfb.paSegs    = (PRTSGSEG)&pThis->Ramfb.papvPages[cPages];
+                PRTGCPHYS paGCPhysPages = (PRTGCPHYS)&pThis->Ramfb.papvPages[cPages];
+
+                for (uint32_t i = 0; i < cPages; i++)
+                {
+                    paGCPhysPages[i] = GCPhysStart;
+                    GCPhysStart += GUEST_PAGE_SIZE;
+                }
+
+                int rc = PDMDevHlpPhysBulkGCPhys2CCPtrReadOnly(pDevIns, cPages, paGCPhysPages, 0 /*fFlags*/,
+                                                               pThis->Ramfb.papvPages, pThis->Ramfb.paPgLocks);
+                if (RT_FAILURE(rc))
+                {
+                    RTMemFree(pThis->Ramfb.paPgLocks);
+                    pThis->Ramfb.paPgLocks = NULL;
+                    pThis->Ramfb.papvPages = NULL;
+                    pThis->Ramfb.paSegs    = NULL;
+                    pThis->Ramfb.cPgLocks  = 0;
+                    return rc;
+                }
+
+                /* Compress the segment pointers. */
+                uint32_t iSeg = 0;
+
+                pThis->Ramfb.paSegs[0].pvSeg = (void *)((const uint8_t *)pThis->Ramfb.papvPages[0] + offPage);
+                pThis->Ramfb.paSegs[0].cbSeg = GUEST_PAGE_SIZE - offPage;
+
+                for (uint32_t i = 1; i < pThis->Ramfb.cPgLocks; ++i)
+                {
+                    /* Contiguous memory mapping? */
+                    if ((uintptr_t)pThis->Ramfb.papvPages[i] == (uintptr_t)pThis->Ramfb.paSegs[iSeg].pvSeg + pThis->Ramfb.paSegs[iSeg].cbSeg)
+                    {
+                        Assert(pThis->Ramfb.paSegs[iSeg].cbSeg);
+                        pThis->Ramfb.paSegs[iSeg].cbSeg += GUEST_PAGE_SIZE;
+                    }
+                    else
+                    {
+                        iSeg++;
+                        pThis->Ramfb.paSegs[iSeg].pvSeg = (void *)pThis->Ramfb.papvPages[i];
+                        pThis->Ramfb.paSegs[iSeg].cbSeg = GUEST_PAGE_SIZE;
+                    }
+                }
+
+                RTSgBufInit(&pThis->Ramfb.SgBuf, pThis->Ramfb.paSegs, iSeg + 1);
+            }
+
+            RTSgBufReset(&pThis->Ramfb.SgBuf);
+            size_t cbCopied = RTSgBufCopyToBuf(&pThis->Ramfb.SgBuf, pThis->pDrvL0->pbData, pThis->RamfbCfg.cbStride * pThis->RamfbCfg.cHeight);
+            Assert(cbCopied == pThis->RamfbCfg.cbStride * pThis->RamfbCfg.cHeight); RT_NOREF(cbCopied);
             AssertPtr(pThis->pDrvL0);
             pThis->pDrvL0->pfnUpdateRect(pThis->pDrvL0, 0, 0, pThis->RamfbCfg.cWidth, pThis->RamfbCfg.cHeight);
         }
@@ -1625,7 +1830,7 @@ static DECLCALLBACK(int) qemuFwCfgR3RamfbPortUpdateDisplay(PPDMIDISPLAYPORT pInt
     else
         LogFlowFunc(("Rendering disabled or no RAM framebuffer set up\n"));
 
-    PDMDevHlpCritSectLeave(pThis->pDevIns, &pThis->CritSectRamfb);
+    PDMDevHlpCritSectLeave(pDevIns, &pThis->CritSectRamfb);
     return VINF_SUCCESS;
 }
 
@@ -1986,6 +2191,15 @@ static DECLCALLBACK(int) qemuFwCfgDestruct(PPDMDEVINS pDevIns)
         RTVfsFileRelease(pThis->hVfsFileInitrd);
     pThis->hVfsFileInitrd = NIL_RTVFSFILE;
 
+    if (pThis->Ramfb.paPgLocks)
+    {
+        RTMemFree(pThis->Ramfb.paPgLocks);
+        pThis->Ramfb.paPgLocks = NULL;
+        pThis->Ramfb.papvPages = NULL;
+        pThis->Ramfb.paSegs    = NULL;
+        pThis->Ramfb.cPgLocks  = 0;
+    }
+
     return VINF_SUCCESS;
 }
 
@@ -2114,6 +2328,15 @@ static DECLCALLBACK(int) qemuFwCfgConstruct(PPDMDEVINS pDevIns, int iInstance, P
         AssertRCReturn(rc, rc);
     }
 
+    /*
+     * Register saved state callbacks.
+     */
+    rc = PDMDevHlpSSMRegisterEx(pDevIns, QEMU_FW_CFG_SAVED_STATE_VERSION, 0 /*cbGuess*/, NULL,
+                                NULL, qemuFwCfgR3LiveExec, NULL,
+                                NULL, qemuFwCfgR3SaveExec, NULL,
+                                NULL, qemuFwCfgR3LoadExec, qemuFwCfgR3LoadDone);
+    AssertRCReturn(rc, rc);
+
     rc = qemuFwCfgInitrdMaybeCreate(pThis);
     if (RT_FAILURE(rc))
         return rc; /* Error set. */
