@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2006-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2006-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -433,8 +433,6 @@ public:
 
 #ifdef VBOX_WITH_DRAG_AND_DROP
         /// @todo move to notification-center as progress notification .. one day :)
-        void cannotDropDataToGuest(const CDnDTarget &dndTarget, QWidget *pParent = 0) const;
-        void cannotDropDataToGuest(const CProgress &progress, QWidget *pParent = 0) const;
         void cannotDropDataToHost(const CDnDSource &dndSource, QWidget *pParent = 0) const;
         void cannotDropDataToHost(const CProgress &progress, QWidget *pParent = 0) const;
 #endif /* VBOX_WITH_DRAG_AND_DROP */
