@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2019-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2019-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -78,20 +78,20 @@ void UIUSBControllerEditor::sltRetranslateUI()
     if (m_pRadioButtonUSB1)
     {
         m_pRadioButtonUSB1->setText(tr("USB &1.1 (OHCI) Controller"));
-        m_pRadioButtonUSB1->setToolTip(tr("When chosen, enables the virtual USB OHCI controller of "
-                                          "this machine. The USB OHCI controller provides USB 1.0 support."));
+        m_pRadioButtonUSB1->setToolTip(tr("Enable virtual USB OHCI controller of this machine. "
+                                          "The USB OHCI controller provides USB 1.0 support."));
     }
     if (m_pRadioButtonUSB2)
     {
         m_pRadioButtonUSB2->setText(tr("USB &2.0 (OHCI + EHCI) Controller"));
-        m_pRadioButtonUSB2->setToolTip(tr("When chosen, enables the virtual USB OHCI and EHCI "
-                                          "controllers of this machine. Together they provide USB 2.0 support."));
+        m_pRadioButtonUSB2->setToolTip(tr("Enable virtual USB OHCI and EHCI controllers of this machine. "
+                                          "Together they provide USB 2.0 support."));
     }
     if (m_pRadioButtonUSB3)
     {
         m_pRadioButtonUSB3->setText(tr("USB &3.0 (xHCI) Controller"));
-        m_pRadioButtonUSB3->setToolTip(tr("When chosen, enables the virtual USB xHCI controller of "
-                                          "this machine. The USB xHCI controller provides USB 3.0 support."));
+        m_pRadioButtonUSB3->setToolTip(tr("Enable virtual USB xHCI controller of this machine. "
+                                          "The USB xHCI controller provides USB 3.0 support."));
     }
 }
 
