@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2006-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2006-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -47,6 +47,61 @@
 #include "iprt/assert.h"
 
 
+/*********************************************************************************************************************************
+*   UIProductKeyLineEdit definition.                                                                                             *
+*********************************************************************************************************************************/
+
+class UIProductKeyLineEdit : public QILineEdit
+{
+    Q_OBJECT;
+public:
+    UIProductKeyLineEdit(QWidget *pParent = 0);
+    QString productKey() const;
+    bool isValid(bool fRequired) const;
+private:
+    static const QString strInputMask;
+};
+
+const QString UIProductKeyLineEdit::strInputMask(">NNNNN-NNNNN-NNNNN-NNNNN-NNNNN;_");
+
+
+/*********************************************************************************************************************************
+*   UIProductKeyLineEdit implementation.                                                                                         *
+*********************************************************************************************************************************/
+
+UIProductKeyLineEdit::UIProductKeyLineEdit(QWidget *pParent /* = 0 */)
+    : QILineEdit(pParent)
+{
+    setInputMask(">NNNNN-NNNNN-NNNNN-NNNNN-NNNNN;_");
+    setMinimumWidthByText("NNNNN-NNNNN-NNNNN-NNNNN-NNNNN");
+}
+
+bool UIProductKeyLineEdit::isValid(bool fRequired) const
+{
+    if (!fRequired)
+    {
+        /* Accept if the line edit is empty after removing separators of the input mask, assuming '-': */
+        if (text().remove('-').isEmpty())
+            return true;
+    }
+    return hasAcceptableInput();
+}
+
+QString UIProductKeyLineEdit::productKey() const
+{
+    /* Return an empty string if text() consists of only separators: */
+    if (text().remove('-').isEmpty())
+        return QString();
+    if (!hasAcceptableInput())
+        return QString();
+    return text();
+}
+
+
+/*********************************************************************************************************************************
+*   UIHostnameDomainNameEditor implementation.                                                                                   *
+*********************************************************************************************************************************/
+
 UIHostnameDomainNameEditor::UIHostnameDomainNameEditor(QWidget *pParent /*  = 0 */)
     : QWidget(pParent)
     , m_pHostnameLineEdit(0)
@@ -68,24 +123,28 @@ QString UIHostnameDomainNameEditor::hostname() const
     return QString();
 }
 
-bool UIHostnameDomainNameEditor::isComplete() const
+bool UIHostnameDomainNameEditor::hostDomainNameComplete() const
 {
     return m_pHostnameLineEdit && m_pHostnameLineEdit->hasAcceptableInput() &&
         m_pDomainNameLineEdit && m_pDomainNameLineEdit->hasAcceptableInput();
 }
 
-void UIHostnameDomainNameEditor::mark()
+void UIHostnameDomainNameEditor::mark(bool fProductKeyRequired)
 {
     if (m_pHostnameLineEdit)
         m_pHostnameLineEdit->mark(!m_pHostnameLineEdit->hasAcceptableInput(),
-                                  tr("Hostname should be at least 2 character long. "
+                                  tr("Host name should be at least 2 character long. "
                                      "Allowed characters are alphanumerics, \"-\" and \".\""),
-                                  tr("Hostname is valid"));
+                                  tr("Host name is valid"));
     if (m_pDomainNameLineEdit)
         m_pDomainNameLineEdit->mark(!m_pDomainNameLineEdit->hasAcceptableInput(),
                                     tr("Domain name should be at least 2 character long. "
                                        "Allowed characters are alphanumerics, \"-\" and \".\""),
                                     tr("Domain name is valid"));
+    if (m_pProductKeyLineEdit)
+        m_pProductKeyLineEdit->mark(!m_pProductKeyLineEdit->isValid(fProductKeyRequired),
+                                    tr("Selected OS requires a valid product key"),
+                                    tr("Product key is valid"));
 }
 
 void UIHostnameDomainNameEditor::setHostname(const QString &strHostname)
@@ -117,27 +176,33 @@ QString UIHostnameDomainNameEditor::hostnameDomainName() const
 void UIHostnameDomainNameEditor::sltRetranslateUI()
 {
     if (m_pHostnameLabel)
-        m_pHostnameLabel->setText(tr("Hostna&me:"));
+        m_pHostnameLabel->setText(tr("Host Na&me"));
     if (m_pHostnameLineEdit)
-        m_pHostnameLineEdit->setToolTip(tr("Holds the hostname."));
+        m_pHostnameLineEdit->setToolTip(tr("Host name to be assigned to the virtual machine"));
     if (m_pDomainNameLabel)
-        m_pDomainNameLabel->setText(tr("&Domain Name:"));
+        m_pDomainNameLabel->setText(tr("&Domain Name"));
     if (m_pDomainNameLineEdit)
-        m_pDomainNameLineEdit->setToolTip(tr("Holds the domain name."));
+        m_pDomainNameLineEdit->setToolTip(tr("Domain name to be assigned to the virtual machine"));
     if (m_pProductKeyLabel)
-        m_pProductKeyLabel->setText(UIWizardNewVM::tr("&Product Key:"));
+        m_pProductKeyLabel->setText(UIWizardNewVM::tr("&Product Key"));
     if (m_pProductKeyLineEdit)
-        m_pProductKeyLineEdit->setToolTip(UIWizardNewVM::tr("Holds the product key."));
+        m_pProductKeyLineEdit->setToolTip(UIWizardNewVM::tr("The product key"));
 
     if (m_pStartHeadlessCheckBox)
     {
         m_pStartHeadlessCheckBox->setText(UIWizardNewVM::tr("&Install in Background"));
-        m_pStartHeadlessCheckBox->setToolTip(UIWizardNewVM::tr("When checked, headless boot (with no GUI) will be enabled for "
-                                                               "unattended guest OS installation of newly created virtual machine."));
+        m_pStartHeadlessCheckBox->setToolTip(UIWizardNewVM::tr("Start the virtual machine without a GUI"));
     }
 }
 
-void UIHostnameDomainNameEditor::addLineEdit(int &iRow, QLabel *&pLabel, QILineEdit *&pLineEdit, QGridLayout *pLayout)
+void UIHostnameDomainNameEditor::sltProductKeyChanged(const QString &strKey)
+{
+    Q_UNUSED(strKey);
+    emit sigProductKeyChanged(m_pProductKeyLineEdit->productKey());
+}
+
+template<typename T>
+void UIHostnameDomainNameEditor::addLineEdit(int &iRow, QLabel *&pLabel, T *&pLineEdit, QGridLayout *pLayout)
 {
     AssertReturnVoid(pLayout);
     if (pLabel || pLineEdit)
@@ -148,7 +213,7 @@ void UIHostnameDomainNameEditor::addLineEdit(int &iRow, QLabel *&pLabel, QILineE
     pLabel->setAlignment(Qt::AlignRight);
     pLayout->addWidget(pLabel, iRow, 0, 1, 1);
 
-    pLineEdit = new QILineEdit;
+    pLineEdit = new T;
     AssertReturnVoid(pLineEdit);
     pLineEdit->setMarkable(true);
 
@@ -170,12 +235,6 @@ void UIHostnameDomainNameEditor::prepare()
     addLineEdit(iRow, m_pHostnameLabel, m_pHostnameLineEdit, m_pMainLayout);
     addLineEdit(iRow, m_pDomainNameLabel, m_pDomainNameLineEdit, m_pMainLayout);
 
-    if (m_pProductKeyLineEdit)
-    {
-        m_pProductKeyLineEdit->setInputMask(">NNNNN-NNNNN-NNNNN-NNNNN-NNNNN;#");
-        m_pProductKeyLineEdit->setMinimumWidthByText("NNNNN-NNNNN-NNNNN-NNNNN-NNNNN");
-    }
-
     /* Host name and domain should be strings of minimum length of 2 and composed of alpha numerics, '-', and '.'
      * Exclude strings with . at the end: */
     m_pHostnameLineEdit->setValidator(new QRegularExpressionValidator(QRegularExpression("^[a-zA-Z0-9-.]{2,}[$a-zA-Z0-9-]"), this));
@@ -186,7 +245,7 @@ void UIHostnameDomainNameEditor::prepare()
     connect(m_pDomainNameLineEdit, &QILineEdit::textChanged,
             this, &UIHostnameDomainNameEditor::sltDomainChanged);
     connect(m_pProductKeyLineEdit, &QILineEdit::textChanged,
-            this, &UIHostnameDomainNameEditor::sigProductKeyChanged);
+            this, &UIHostnameDomainNameEditor::sltProductKeyChanged);
 
     sltRetranslateUI();
     connect(&translationEventListener(), &UITranslationEventListener::sigRetranslateUI,
@@ -206,10 +265,10 @@ void UIHostnameDomainNameEditor::prepare()
 void UIHostnameDomainNameEditor::sltHostnameChanged()
 {
     m_pHostnameLineEdit->mark(!m_pHostnameLineEdit->hasAcceptableInput(),
-                              tr("Hostname should be at least 2 character long. "
+                              tr("Host name should be at least 2 character long. "
                                  "Allowed characters are alphanumerics, \"-\" and \".\""),
-                              tr("Hostname is valid"));
-    emit sigHostnameDomainNameChanged(hostnameDomainName(), isComplete());
+                              tr("Host name is valid"));
+    emit sigHostnameDomainNameChanged(hostnameDomainName(), hostDomainNameComplete());
 }
 
 void UIHostnameDomainNameEditor::sltDomainChanged()
@@ -218,7 +277,7 @@ void UIHostnameDomainNameEditor::sltDomainChanged()
                                 tr("Domain name should be at least 2 character long. "
                                    "Allowed characters are alphanumerics, \"-\" and \".\""),
                                 tr("Domain name is valid"));
-    emit sigHostnameDomainNameChanged(hostnameDomainName(), isComplete());
+    emit sigHostnameDomainNameChanged(hostnameDomainName(), hostDomainNameComplete());
 }
 
 void UIHostnameDomainNameEditor::disableEnableProductKeyWidgets(bool fEnabled)
@@ -228,3 +287,16 @@ void UIHostnameDomainNameEditor::disableEnableProductKeyWidgets(bool fEnabled)
     if (m_pProductKeyLineEdit)
         m_pProductKeyLineEdit->setEnabled(fEnabled);
 }
+
+bool UIHostnameDomainNameEditor::isProductKeyValid(bool fProductKeyRequired) const
+{
+    return m_pProductKeyLineEdit->isValid(fProductKeyRequired);
+}
+
+QString UIHostnameDomainNameEditor::productKey() const
+{
+    if (m_pProductKeyLineEdit)
+        return m_pProductKeyLineEdit->productKey();
+    return QString();
+}
+#include "UIHostnameDomainNameEditor.moc"
