@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2012-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2012-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -31,6 +31,10 @@
 # pragma once
 #endif
 
+#ifdef IN_VBOXSVC
+# error "Using RecordingInternals.h is prohibited in VBoxSVC!"
+#endif
+
 #include <list>
 #include <map>
 
@@ -53,6 +57,8 @@
 # include "vorbis/vorbisenc.h"
 #endif
 
+#include "RecordingContext.h" /* For RECORDINGPIXELFMT. */
+
 
 /*********************************************************************************************************************************
 *   Defines                                                                                                                      *
@@ -75,22 +81,6 @@ typedef RECORDINGFRAME *PRECORDINGFRAME;
 *   Internal structures, defines and APIs                                                                                        *
 *********************************************************************************************************************************/
 
-/** List for keeping a recording feature list. */
-typedef std::map<RecordingFeature_T, bool> RecordingFeatureMap;
-
-/**
- * Enumeration for supported pixel formats.
- */
-enum RECORDINGPIXELFMT
-{
-    /** Unknown pixel format. */
-    RECORDINGPIXELFMT_UNKNOWN    = 0,
-    /** BRGA 32. */
-    RECORDINGPIXELFMT_BRGA32     = 1,
-    /** The usual 32-bit hack. */
-    RECORDINGPIXELFMT_32BIT_HACK = 0x7fffffff
-};
-
 /**
  * Structure for keeping recording surface information.
  */
@@ -562,6 +552,7 @@ struct RecordingBlock
     RecordingBlock()
         : cRefs(0)
         , uFlags(RECORDINGCODEC_ENC_F_NONE)
+        , msTimestamp(0)
         , pvData(NULL)
         , cbData(0) { }
 
