@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2022-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2022-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -65,7 +65,6 @@
 #include <VBox/vmm/pdmaudioifs.h>
 #include <VBox/vmm/pdmaudioinline.h>
 
-#include "Recording.h"
 #include "RecordingInternals.h"
 #include "RecordingUtils.h"
 #include "WebMWriter.h"
@@ -509,8 +508,10 @@ static DECLCALLBACK(int) recordingCodecVPXEncode(PRECORDINGCODEC pCodec, PRECORD
     vrc = RecordingUtilsCoordsCropCenter(&pCodec->Parms, &sx, &sy, &sw, &sh, &dx, &dy);
     if (vrc == VINF_SUCCESS) /* vrc might be VWRN_RECORDING_ENCODING_SKIPPED to skip encoding. */
     {
-        Log3Func(("Encoding source %RI32,%RI32 (%RI32x%RI32) to %RI32,%RI32 (%zu bytes)\n",
-                  sx, sy, sw, sh, dx, dy, sw * sh * (pFront->Info.uBPP / 8)));
+        Log3Func(("Encoding source %RI32,%RI32 (%RI32x%RI32) to dest %RI32,%RI32 (%RU32x%RU32) -- %zu bytes\n",
+                  sx, sy, sw, sh,
+                  dx, dy, pCodec->Parms.u.Video.uWidth, pCodec->Parms.u.Video.uHeight,
+                  (size_t)(sw * sh * (pFront->Info.uBPP / 8))));
 #if 0
         AssertReturn(sw + dx <= (int32_t)pCodec->Parms.u.Video.uWidth,  VERR_INVALID_PARAMETER);
         AssertReturn(sy + sh <= (int32_t)pCodec->Parms.u.Video.uHeight, VERR_INVALID_PARAMETER);
@@ -701,7 +702,9 @@ static DECLCALLBACK(int) recordingCodecVorbisEncode(PRECORDINGCODEC pCodec,
         return VERR_RECORDING_ENCODING_FAILED;
     }
 
+#ifdef LOG_ENABLED
     size_t cBlocksEncoded = 0;
+#endif
     size_t cBytesEncoded  = 0;
 
     uint8_t *puDst = (uint8_t *)pCodec->pvScratch;
@@ -734,8 +737,9 @@ static DECLCALLBACK(int) recordingCodecVorbisEncode(PRECORDINGCODEC pCodec,
         {
             cBytesEncoded += op.bytes;
             AssertBreakStmt(cBytesEncoded <= pCodec->cbScratch, vrc = VERR_BUFFER_OVERFLOW);
+#ifdef LOG_ENABLED
             cBlocksEncoded++;
-
+#endif
             vrc = pCodec->Callbacks.pfnWriteData(pCodec, op.packet, (size_t)op.bytes, pCodec->State.tsLastWrittenMs,
                                                  RECORDINGCODEC_ENC_F_BLOCK_IS_KEY /* Every Vorbis frame is a key frame */,
                                                  pCodec->Callbacks.pvUser);
