@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2006-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2006-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -207,9 +207,10 @@ static VBOXSTRICTRC iomMmioDoComplicatedWrite(PVM pVM, PVMCPU pVCpu, CTX_SUFF(PI
         uint32_t u32MissingValue = 0;
         if (fReadMissing && cbThisPart != 4)
         {
-            VBOXSTRICTRC rc2 = pRegEntry->pfnReadCallback(pRegEntry->pDevIns, pRegEntry->pvUser,
-                                                          !(pRegEntry->fFlags & IOMMMIO_FLAGS_ABS)
-                                                          ? offRegion & ~(RTGCPHYS)3 : (GCPhys & ~(RTGCPHYS)3),
+            RTGCPHYS offArgRead = (!(pRegEntry->fFlags & IOMMMIO_FLAGS_ABS) ? offRegion & ~(RTGCPHYS)3 : (GCPhys & ~(RTGCPHYS)3))
+                                | (!(pRegEntry->fFlags & IOMMMIO_FLAGS_SET_HI_OFF_BIT_READING_MISSING)
+                                   ? 0 : IOMMMIO_OFF_F_READING_MISSING_BYTES);
+            VBOXSTRICTRC rc2 = pRegEntry->pfnReadCallback(pRegEntry->pDevIns, pRegEntry->pvUser, offArgRead,
                                                           &u32MissingValue, sizeof(u32MissingValue));
             switch (VBOXSTRICTRC_VAL(rc2))
             {
@@ -1002,7 +1003,8 @@ DECLCALLBACK(VBOXSTRICTRC) iomMmioHandlerNew(PVMCC pVM, PVMCPUCC pVCpu, RTGCPHYS
          * Check the return code.
          */
 #ifdef IN_RING3
-        AssertMsg(rcStrict == VINF_SUCCESS, ("%Rrc -  Access type %d - %RGp - %s\n",
+        AssertMsg(   rcStrict == VINF_SUCCESS
+                  || rcStrict == VINF_EM_DBG_STEP, ("%Rrc -  Access type %d - %RGp - %s\n",
                                              VBOXSTRICTRC_VAL(rcStrict), enmAccessType, GCPhysFault, pRegEntry->pszDesc));
 #else
         AssertMsg(   rcStrict == VINF_SUCCESS
@@ -1319,8 +1321,8 @@ VMMDECL(int) IOMMmioResetRegion(PVMCC pVM, PPDMDEVINS pDevIns, IOMMMIOHANDLE hRe
             RTHCPHYS HCPhys;
             rc = PGMShwGetPage(pVCpu, (RTGCPTR)GCPhys, &fFlags, &HCPhys);
             Assert(rc == VERR_PAGE_NOT_PRESENT || rc == VERR_PAGE_TABLE_NOT_PRESENT);
-            cb     -= RT_MIN(GUEST_PAGE_SIZE, HOST_PAGE_SIZE);
-            GCPhys += RT_MIN(GUEST_PAGE_SIZE, HOST_PAGE_SIZE);
+            cb     -= RT_MIN(GUEST_PAGE_SIZE, HOST_PAGE_SIZE_DYNAMIC);
+            GCPhys += RT_MIN(GUEST_PAGE_SIZE, HOST_PAGE_SIZE_DYNAMIC);
         }
     }
 # endif
