@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2007-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2007-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -69,8 +69,8 @@ BS3_CMN_DEF(void, Bs3Trap16InitEx,(bool f386Plus))
     {
         uint8_t BS3_FAR_DATA *pbFunction = &bs3Trap16GenericTrapOrInt[0];
 #if ARCH_BITS == 16
-        if (g_bBs3CurrentMode != BS3_MODE_RM)
-            pbFunction = (uint8_t BS3_FAR_DATA *)BS3_FP_MAKE(BS3_SEL_TILED + 1, BS3_FP_OFF(pbFunction));
+        if (g_bBs3CurrentMode != BS3_MODE_RM) /* Code seg isn't writable in prot mode. Do manual conversion to titled address. */
+            pbFunction = (uint8_t BS3_FAR_DATA *)BS3_FP_MAKE(BS3_SEL_TILED + 8, BS3_FP_OFF(pbFunction));
 #endif
         pbFunction[1] = 0;
         pbFunction[2] = 0;
