@@ -8,7 +8,7 @@ TestBox Script - main().
 
 __copyright__ = \
 """
-Copyright (C) 2012-2024 Oracle and/or its affiliates.
+Copyright (C) 2012-2025 Oracle and/or its affiliates.
 
 This file is part of VirtualBox base platform packages, as
 available from https://www.virtualbox.org.
@@ -37,7 +37,7 @@ terms and conditions of either the GPL or the CDDL or both.
 
 SPDX-License-Identifier: GPL-3.0-only OR CDDL-1.0
 """
-__version__ = "$Revision: 165070 $"
+__version__ = "$Revision: 170825 $"
 
 
 # Standard python imports.
@@ -199,6 +199,9 @@ class TestBoxScript(object):
         testboxcommons.log('Starting Test Box script (%s)' % (self._getScriptRev(),));
         testboxcommons.log('Test Manager URL: %s' % self._oOptions.sTestManagerUrl,)
         testboxcommons.log('Scratch root path: %s' % self._oOptions.sScratchRoot,)
+        if self._oOptions.sResourceCacheRoot is not None:
+            testboxcommons.log('Local resource cache root path: %s' % self._oOptions.sResourceCacheRoot,);
+            testboxcommons.log('Local resource cache maximum size: %s' % self._oOptions.sResourceCacheSizeMax,);
         for sItem in self._ddSignOnParams:                      # pylint: disable=consider-using-dict-items
             testboxcommons.log('Sign-On value %18s: %s' % (sItem, self._ddSignOnParams[sItem][self.VALUE]));
 
@@ -246,6 +249,9 @@ class TestBoxScript(object):
         os.environ['TESTBOX_TEST_SET_ID']       = '';
         os.environ['TESTBOX_TIMEOUT']           = '0';
         os.environ['TESTBOX_TIMEOUT_ABS']       = '0';
+        if self._oOptions.sResourceCacheRoot is not None:
+            os.environ['TESTBOX_PATH_RESOURCES_CACHE']          = self._oOptions.sResourceCacheRoot;
+            os.environ['TESTBOX_PATH_RESOURCES_CACHE_SIZE_MAX'] = self._oOptions.sResourceCacheSizeMax;
 
         if utils.getHostOs() == 'win':
             os.environ['COMSPEC']            = os.path.join(os.environ['SystemRoot'], 'System32', 'cmd.exe');
@@ -302,6 +308,8 @@ class TestBoxScript(object):
                 raise TestBoxScriptException('Unsupported server type %s.' % (sType,));
 
         elif sHostOs == 'linux':
+            if sShare == 'builds':
+                sMountOpt = 'vers=2.1'  # right now only linux unhappy with builds mount, adding vers to avoid it
             if sMountOpt != '':
                 sMountOpt = ',' + sMountOpt
             utils.sudoProcessCall(['/bin/umount', sMountPoint]);
@@ -992,6 +1000,14 @@ class TestBoxScript(object):
                           dest="sScratchRoot",
                           help="Path to the scratch directory",
                           default=None)
+        parser.add_option("--testrsrc-cache-root", metavar="<abs-path>",
+                          dest="sResourceCacheRoot",
+                          help="Path to the optional local resource cache directory",
+                          default=None)
+        parser.add_option("--testrsrc-cache-size-max", metavar="<size>",
+                          dest="sResourceCacheSizeMax",
+                          help="Maximum size of the local resource cache in bytes",
+                          default=None)
         parser.add_option("--system-uuid", metavar="<uuid>",
                           dest="sSystemUuid",
                           help="The system UUID of the testbox, used for uniquely identifiying the machine",
