@@ -1,3 +1,4 @@
+
 /********************************************************************************/
 /*										*/
 /*			   Attestation Commands  				*/
@@ -22,7 +23,7 @@
 /*										*/
 /*  2. Source Code Distribution Conditions:					*/
 /*										*/
-/*  - Redistributions of Source Code must retain the above copyright licenses, 	*/
+/*  - Redistributions of Source CoDe must retain the above copyright licenses, 	*/
 /*    this list of conditions and the following disclaimers.			*/
 /*										*/
 /*  - Redistributions in binary form must reproduce the above copyright 	*/
@@ -94,7 +95,7 @@ TPM2_Certify(
 	certifyInfo.attested.certify.qualifiedName.t.size = 0;
     else
 	certifyInfo.attested.certify.qualifiedName = certifiedObject->qualifiedName;
-    
+
     // Sign attestation structure.  A NULL signature will be returned if
     // signHandle is TPM_RH_NULL.  A TPM_RC_NV_UNAVAILABLE, TPM_RC_NV_RATE,
     // TPM_RC_VALUE, TPM_RC_SCHEME or TPM_RC_ATTRIBUTES error may be returned
@@ -309,13 +310,12 @@ TPM2_GetTime(
 #include "Tpm.h"
 #include "CertifyX509_fp.h"
 #include "X509.h"
-#include "TpmAsn1_fp.h"
+#include "TpmASN1_fp.h"
 #include "X509_spt_fp.h"
 #include "Attest_spt_fp.h"
-#include "Platform_fp.h"
 #if CC_CertifyX509 // Conditional expansion of this file
 #if CERTIFYX509_DEBUG
-#include "DebugHelpers_fp.h"
+#  include "tpm_to_platform_interface.h"
 #endif
 
 /* Error Returns	Meaning*/
@@ -352,7 +352,7 @@ TPM2_CertifyX509(
     DebugDumpBuffer(in->partialCertificate.t.size, in->partialCertificate.t.buffer,
 		    "partialCertificate");
 #endif
-    
+
     // Input Validation
     if(in->reserved.b.size != 0)
 	return TPM_RC_SIZE + RC_CertifyX509_reserved;
@@ -419,13 +419,13 @@ TPM2_CertifyX509(
     // belong
     for(i = 0; i < countOfSequences; i++)
 	certTBS[SUBJECT_KEY_REF - i] = partial[countOfSequences - 1 - i];
-    
+
     // If only three SEQUENCES, then the TPM needs to produce the signature algorithm.
     // See if it can
     if((countOfSequences == 3) &&
        (X509AddSigningAlgorithm(NULL, signKey, &in->inScheme) == 0))
 	return TPM_RCS_SCHEME + RC_CertifyX509_signHandle;
-    
+
     // Process the extensions
     result = X509ProcessExtensions(object, &certTBS[EXTENSIONS_REF]);
     if(result != TPM_RC_SUCCESS)
@@ -437,14 +437,14 @@ TPM2_CertifyX509(
 			 : RC_CertifyX509_partialCertificate);
     // Command Output
     // Create the addedToCertificate values
-    
+
     // Build the addedToCertificate from the bottom up.
     // Initialize the context structure
     ASN1InitialializeMarshalContext(&ctxOut, sizeof(out->addedToCertificate.t.buffer),
 				    out->addedToCertificate.t.buffer);
     // Place a marker for the overall context
     ASN1StartMarshalContext(&ctxOut);  // SEQUENCE for addedToCertificate
-    
+
     // Add the subject public key descriptor
     certTBS[SUBJECT_PUBLIC_KEY_REF].len = X509AddPublicKey(&ctxOut, object);
     certTBS[SUBJECT_PUBLIC_KEY_REF].buf = ctxOut.buffer + ctxOut.offset;
@@ -461,7 +461,7 @@ TPM2_CertifyX509(
 	//
 	digest->size = (INT16)CryptHashStart(&hash, signKey->publicArea.nameAlg);
 	pAssert(digest->size != 0);
-	
+
 	// The serial number size is the smaller of the digest and the vendor-defined
 	// value
 	digest->size = MIN(digest->size, SIZE_OF_X509_SERIAL_NUMBER);
@@ -476,19 +476,19 @@ TPM2_CertifyX509(
 	// Done
 	CryptHashEnd2B(&hash, digest);
     }
-    
+
     // Add the serial number
     certTBS[SERIAL_NUMBER_REF].len =
 	ASN1PushInteger(&ctxOut, out->tbsDigest.t.size, out->tbsDigest.t.buffer);
     certTBS[SERIAL_NUMBER_REF].buf = ctxOut.buffer + ctxOut.offset;
-    
+
     // Add the static version number
     ASN1StartMarshalContext(&ctxOut);
     ASN1PushUINT(&ctxOut, 2);
     certTBS[VERSION_REF].len =
 	ASN1EndEncapsulation(&ctxOut, ASN1_APPLICAIION_SPECIFIC);
     certTBS[VERSION_REF].buf = ctxOut.buffer + ctxOut.offset;
-    
+
     // Create a fake tag and length for the TBS in the space used for
     // 'addedToCertificate'
     {
@@ -510,7 +510,7 @@ TPM2_CertifyX509(
     for(i = 0; i < REF_COUNT; i++)
 	CryptDigestUpdate(&hash, certTBS[i].len, certTBS[i].buf);
     CryptHashEnd2B(&hash, &out->tbsDigest.b);
-    
+
 #if CERTIFYX509_DEBUG
     {
 	BYTE                 fullTBS[4096];
@@ -524,7 +524,7 @@ TPM2_CertifyX509(
 	DebugDumpBuffer((int)(fill - &fullTBS[0]), fullTBS, "\nfull TBS");
     }
 #endif
-    
+
     // Finish up the processing of addedToCertificate
     // Create the actual tag and length for the addedToCertificate structure
     out->addedToCertificate.t.size =
@@ -538,7 +538,7 @@ TPM2_CertifyX509(
 #endif
     // only thing missing is the signature
     result = CryptSign(signKey, &in->inScheme, &out->tbsDigest, &out->signature);
-    
+
     return result;
 }
 #endif // CC_CertifyX509
