@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2016-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2016-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -164,7 +164,8 @@ void ossl_rcu_lock_free(CRYPTO_RCU_LOCK *lock)
     /* make sure we're synchronized */
     ossl_synchronize_rcu(rlock);
 
-    AssertRC(RTSemRWDestroy(rlock->rw_lock));
+    int rc = RTSemRWDestroy(rlock->rw_lock);
+    AssertRC(rc);
     OPENSSL_free(rlock);
 }
 # endif /* VBOX_OPENSSL_WITH_RCU_SUPPORT */
@@ -347,6 +348,18 @@ int CRYPTO_atomic_load(uint64_t *val, uint64_t *ret, CRYPTO_RWLOCK *lock)
     return 1;
 }
 
+int CRYPTO_atomic_load_int(int *val, int *ret, CRYPTO_RWLOCK *lock)
+{
+    *ret = ASMAtomicReadS32(val);
+    return 1;
+}
+
+int CRYPTO_atomic_store(uint64_t *dst, uint64_t val, CRYPTO_RWLOCK *lock)
+{
+    ASMAtomicWriteU64(dst, val);
+    return 1;
+}
+
 #endif /* defined(OPENSSL_THREADS) */
 
 int openssl_init_fork_handlers(void)
