@@ -5,7 +5,7 @@
 #
 
 #
-# Copyright (C) 2009-2024 Oracle and/or its affiliates.
+# Copyright (C) 2009-2025 Oracle and/or its affiliates.
 #
 # This file is part of VirtualBox base platform packages, as
 # available from https://www.virtualbox.org.
@@ -275,21 +275,21 @@ my_generate_all_projects()
     my_generate_project "Add-Vbgl"      "src/VBox/Additions/common/VBoxGuest/lib" --begin-incs "include" "src/VBox/Additions/common/VBoxGuest/lib" --end-includes "src/VBox/Additions/common/VBoxGuest/lib" "include/VBox/VBoxGuest/lib/*.*"
     my_generate_project "Add-VBoxService" "src/VBox/Additions/common/VBoxService" --begin-incs "include" "src/VBox/Additions/common/VBoxService"  --end-includes "src/VBox/Additions/common/VBoxService"
     my_generate_project "Add-VBoxVideo" "src/VBox/Additions/common/VBoxVideo"   --begin-incs "include" "src/VBox/Additions/common/VBoxVideo"    --end-includes "src/VBox/Additions/common/VBoxVideo"
-    my_generate_project "Add-nt-Tray"   "src/VBox/Additions/win/VBoxTray"       --begin-incs "include" "src/VBox/Additions/win/include" "src/VBox/Additions/win/VBoxTray" --end-includes "src/VBox/Additions/win/VBoxTray"
+    my_generate_project "Add-nt-Tray"   "src/VBox/Additions/WINNT/VBoxTray"     --begin-incs "include" "src/VBox/Additions/WINNT/include" "src/VBox/Additions/WINNT/VBoxTray" --end-includes "src/VBox/Additions/WINNT/VBoxTray"
     if test -z "$MY_OPT_MINIMAL"; then
-        my_generate_project "Add-cmn-pam"       "src/VBox/Additions/common/pam"           --begin-incs "include" "src/VBox/Additions/common/pam"        --end-includes "src/VBox/Additions/common/pam"
-        my_generate_project "Add-cmn-test"      "src/VBox/Additions/common/testcase"      --begin-incs "include" "src/VBox/Additions/common/testcase"   --end-includes "src/VBox/Additions/common/testcase"
+        my_generate_project "Add-cmn-pam"       "src/VBox/Additions/common/pam"         --begin-incs "include" "src/VBox/Additions/common/pam"          --end-includes "src/VBox/Additions/common/pam"
+        my_generate_project "Add-cmn-test"      "src/VBox/Additions/common/testcase"    --begin-incs "include" "src/VBox/Additions/common/testcase"     --end-includes "src/VBox/Additions/common/testcase"
         mesa=$(my_get_newest_ver src/VBox/Additions/3D/mesa/mesa)
-        my_generate_project "Add-3D-Mesa"       "${mesa}"                                 --begin-incs "include" "${mesa}/include"                      --end-includes "${mesa}"
-        my_generate_project "Add-3D-win"        "src/VBox/Additions/3D/win"               --begin-incs "include" "src/VBox/Additions/3D/win/include" "${mesa}/include" --end-includes "src/VBox/Additions/3D/win"
-        my_generate_project "Add-nt-Graphics"   "src/VBox/Additions/win/Graphics"         --begin-incs "include" "src/VBox/Additions/win/Graphics/Video/common" "src/VBox/Additions/win/include" "src/VBox/Additions/3D/win/include" "${mesa}/include" --end-includes "src/VBox/Additions/win/Graphics"
-        my_generate_project "Add-nt-Installer"  "src/VBox/Additions/win/Installer"        --begin-incs "include" "src/VBox/Additions/win/include"       --end-includes "src/VBox/Additions/win/Installer"
-        my_generate_project "Add-nt-Mouse"      "src/VBox/Additions/win/Mouse"            --begin-incs "include" "src/VBox/Additions/win/include"       --end-includes "src/VBox/Additions/win/Mouse"
-        my_generate_project "Add-nt-SharedFolders" "src/VBox/Additions/win/SharedFolders" --begin-incs "include" "src/VBox/Additions/win/include"       --end-includes "src/VBox/Additions/win/SharedFolders"
-        my_generate_project "Add-nt-tools"      "src/VBox/Additions/win/tools"            --begin-incs "include" "src/VBox/Additions/win/include"       --end-includes "src/VBox/Additions/win/tools"
-        my_generate_project "Add-nt-CredProv"   "src/VBox/Additions/win/VBoxCredProv"     --begin-incs "include" "src/VBox/Additions/win/VBoxCredProv"  --end-includes "src/VBox/Additions/win/VBoxCredProv"
-        my_generate_project "Add-nt-GINA"       "src/VBox/Additions/win/VBoxGINA"         --begin-incs "include" "src/VBox/Additions/win/VBoxGINA"      --end-includes "src/VBox/Additions/win/VBoxGINA"
-        my_generate_project "Add-nt-Hook"       "src/VBox/Additions/win/VBoxHook"         --begin-incs "include" "src/VBox/Additions/win/include"       --end-includes "src/VBox/Additions/win/VBoxHook"
+        my_generate_project "Add-3D-Mesa"       "${mesa}"                               --begin-incs "include" "${mesa}/include" --end-includes "${mesa}"
+        my_generate_project "Add-3D-win"        "src/VBox/Additions/3D/win"             --begin-incs "include" "src/VBox/Additions/3D/win/include" "${mesa}/include" --end-includes "src/VBox/Additions/3D/win"
+        my_generate_project "Add-nt-Graphics"   "src/VBox/Additions/WINNT/Graphics"     --begin-incs "include" "src/VBox/Additions/WINNT/Graphics/Video/common" "src/VBox/Additions/WINNT/include" "src/VBox/Additions/3D/win/include" "${mesa}/include" --end-includes "src/VBox/Additions/WINNT/Graphics"
+        my_generate_project "Add-nt-Installer"  "src/VBox/Additions/WINNT/Installer"    --begin-incs "include" "src/VBox/Additions/WINNT/include"       --end-includes "src/VBox/Additions/WINNT/Installer"
+        my_generate_project "Add-nt-Mouse"      "src/VBox/Additions/WINNT/Mouse"        --begin-incs "include" "src/VBox/Additions/WINNT/include"       --end-includes "src/VBox/Additions/WINNT/Mouse"
+        my_generate_project "Add-nt-SharedFolders" "src/VBox/Additions/WINNT/SharedFolders" --begin-incs "include" "src/VBox/Additions/WINNT/include"   --end-includes "src/VBox/Additions/WINNT/SharedFolders"
+        my_generate_project "Add-nt-tools"      "src/VBox/Additions/WINNT/tools"        --begin-incs "include" "src/VBox/Additions/WINNT/include"       --end-includes "src/VBox/Additions/WINNT/tools"
+        my_generate_project "Add-nt-CredProv"   "src/VBox/Additions/WINNT/VBoxCredProv" --begin-incs "include" "src/VBox/Additions/WINNT/VBoxCredProv"  --end-includes "src/VBox/Additions/WINNT/VBoxCredProv"
+        my_generate_project "Add-nt-GINA"       "src/VBox/Additions/WINNT/VBoxGINA"     --begin-incs "include" "src/VBox/Additions/WINNT/VBoxGINA"      --end-includes "src/VBox/Additions/WINNT/VBoxGINA"
+        my_generate_project "Add-nt-Hook"       "src/VBox/Additions/WINNT/VBoxHook"     --begin-incs "include" "src/VBox/Additions/WINNT/include"       --end-includes "src/VBox/Additions/WINNT/VBoxHook"
     fi
 
     # src/VBox/Debugger
